function strong = trainBOOST(doPrints, trainNorm,T,classes,coding,M,minSize)
% usage: strong = trainBOOST(trainNorm,T,classes,coding,M,minSize)
%**************************************************************************
% INPUT:
% trainNorm: data strcutrue with normalized training data
% T: adaBoost rounds (number of weak learners)
% classes: cell array with classes names
% coding: binary classifier training mode (OneVsOne, OneVsAll, Sublineal)
% M: ecoc matrix (used only in Sublineal mode)
%
% OUTPUT
% strong: cell array containing the set of trained binary classifiers
%**************************************************************************
% 14/04/2010
% fixed bug on 'OneVsAll' coding in the number of examples for data2, now
% equal to data1
%**************************************************************************
% 16/06/2010
% added 'Sublineal' mode
%**************************************************************************
% 12/05/2011
% cast to double for data matrices
%**************************************************************************
% fciompi@maia.ub.es
%**************************************************************************

if((nargin<5)&&(strcmp(coding,'Sublineal')))
    error('trainBOOST with Sublineal coding needs the ECOC matrix as input!');
end

% cell array for final data
strong = {};

fprintf('UPDATE THE CODE FOR NOT-STRUCTURED DATA AS WELL!!\n');

if(strcmp(coding,'OneVsOne'))
    
    % 1vs1
    for t = 1:(length(classes)-1)
        % assign label the the first class
        class1 = classes{t};
        cmd = ['data1 = trainNorm.',class1,';']; eval(cmd);
        
        data1 = double(data1);
        
        for u = t+1:length(classes)  
            class2 = classes{u};
            cmd = ['data2 = trainNorm.',class2,';']; eval(cmd);  
            
            data2 = double(data2);
            
            fprintf('%s vs %s\n',class1,class2);
    
            % boosting
            strong{end+1} = BoostROC(doPrints, data1, data2, T);
            
         end
    end
    
elseif(strcmp(coding,'OneVsAll'))
    
    % 1vsAll
    for t = 1:length(classes)
        % assign label the the first class
        class1 = classes{t};
        cmd = ['data1 = trainNorm.',class1,';']; eval(cmd);
        
        data1 = double(data1);
        
        data2 = [];
        for u = 1:length(classes)
            if(u~=t)
                class2 = classes{u};
                cmd = ['temp = trainNorm.',class2,';']; eval(cmd);
                tempSub = randSubsample(temp,ceil(size(data1,1)/(length(classes)-1)));
                data2 = [data2; tempSub]; clear temp;
            end
        end
        
        data2 = double(data2);
        
        fprintf('%s vs All\n',class1);
        
        % boosting
        strong{end+1} = BoostROC(doPrints, data1, data2, T);

    end
    
elseif(strcmp(coding,'Sublineal'))
        
    % in sublineal, the ecoc matrix is usually created by joining binary
    % coding and Gray coding:
    % 
    %       bin    gray 
    % 1 -> 0 0 1 | 0 0 1
    % 2 -> 0 1 0 | 0 1 1
    % 3 -> 0 1 1 | 0 1 0
    % 4 -> 1 0 0 | 1 1 0
    
    for k = 1:size(M,2)
        
        idx1 = find(M(:,k)==1); % indexes for class1
        idx2 = find(M(:,k)==-1); % indexes for class2
        
        % establish the subsample size
        len1 = []; len2 = [];
        str1 = []; str2 = [];
        for i = 1:length(idx1)
            eval(['thisLen = size(trainNorm.',classes{idx1(i)},',1);']);
            if(thisLen<minSize)
                thisLen = minSize;
            end
            len1 = [len1 thisLen];
            str1 = [str1,'',num2str(idx1(i)),','];
        end
        for i = 1:length(idx2)
            eval(['thisLen = size(trainNorm.',classes{idx2(i)},',1);']);
            if(thisLen<minSize)
                thisLen = minSize;
            end
            len2 = [len2 thisLen];
            str2 = [str2,'',num2str(idx2(i)),','];
        end
        L1 = length(len1)*min(len1);
        L2 = length(len2)*min(len2);
        
        classSize = min(L1,L2); % total size for class1 and class2
        
        % creating classes
        data1 = []; data2 = [];
        for i = 1:length(idx1)
            eval(['data1 = [data1; randSubsample(trainNorm.',classes{idx1(i)},',floor(classSize/length(idx1)))];']);
        end
        for i = 1:length(idx2)
            eval(['data2 = [data2; randSubsample(trainNorm.',classes{idx2(i)},',floor(classSize/length(idx2)))];']);
        end
        
        data1 = double(data1);
        data2 = double(data2);
        
        % training boost
        fprintf('%s vs %s\n',str1,str2);
               
        % boosting
        strong{end+1} = BoostROC(doPrints, data1, data2, T);
        
    end
    
else
    
    error('STRONG training mode not correct!');

end
    



