%%
%   Creates the NP vs P+SP part from the combined classifiers
%   
%   Length PROTOTYPES: Time (x6 0,0,0,0,0,0) and the rest the same
%   Length TrainFeatures: No Time and the rest the same
function trainCombinedClassifier1(varargin)
    tic
    global classes;
    global app_path;
%     method = 'AdaBoost';
    method = 'KNN';
    
    % Says if the sets must be balanced
    balanced = true;
    
    % builds path
    path = regexp(mfilename('fullpath'), '\', 'split');
    path = path(1:end-2); auxpath = path{1};
    for i = 2:length(path)
        auxpath = [auxpath '\' path{i}]; 
    end
    app_path = [auxpath '\Labeling\Demo Labeling - WORKING COPY'];
    
    numOfAdaBoostClassifiers = 1500;
    numNearestNeighboursKNN = 15;
    labels_cell = {}; % Stores the different labels of our images
    F = {}; % Stores a cell matrix with the list of features of for each label

    ids = {'No Plate', 'Plate & Semi-plate'};
    joined_labels = [2 3];
    loadClasses();
    videos_path = [app_path '\result_files'];
    silent = false;
    
    numOldClasses = length(classes);
    lenClasses = numOldClasses - 1;
    
    % Gets the dir list
    fileList = dir([videos_path]);
    dirList = {};
    len = length(fileList);
    for i = 3:len
        if(isdir([videos_path '\' fileList(i).name]))
            dirList = [dirList fileList(i).name];
        end
    end
    
    % Gets the arguments if any
    if(nargin == 4)
        method = varargin{1};
        numNearestNeighboursKNN = varargin{2};
        silent = varargin{3};
        sets = varargin{4};
        dirList = {};
        for i = 1:length(sets)
            dirList = [dirList sets{i}];
        end
        balanced = true;
    end
    
    % Gets a cell with all the classes names
    for i = 1:lenClasses
        labels_cell(i) = {['label_' num2str(classes(i).id)]};
    end
    
    % Counts the number of images for each label
    lenFiles = length(dirList);
    vecNumImgs = zeros(lenClasses,1);
    idxClasses = {};
    for i = 1:lenClasses
        idxClasses{i} = [];
    end
    totalLength = 1;
    for i = 1:lenFiles
        labels_result = load([videos_path '\' dirList{i} '\labels_result_' dirList{i} '.mat']);
        labels_result = labels_result.labels_result;
        partialLen = size(labels_result, 2);
        
        for j = 1:partialLen
            label = labels_result(j).label;
            
            if(any(joined_labels==label))
                idxClasses{joined_labels(1)} = [idxClasses{joined_labels(1)} totalLength];
                vecNumImgs(joined_labels(1)) = vecNumImgs(joined_labels(1)) + 1;
            else
                idxClasses{label} = [idxClasses{label} totalLength];
                vecNumImgs(label) = vecNumImgs(label) + 1;
            end
            totalLength = totalLength+1;

        end
    end
    
    if(balanced)
        vecNumImgsTotal = vecNumImgs;
        balancedNum = min(vecNumImgs);
        for i = 1:lenClasses
            vecNumImgs(i) = balancedNum;
        end
    end
    

    % Loads one features file to know the needed length of the vector
    % We eliminate the features related to the Time (6 components)
    sizeTime = 6;
    features = load([videos_path '\' dirList{1} '\features.mat']);
    lenFeatures = size(features.F, 2);
    for i = 1:lenClasses
        F{i} = zeros(vecNumImgs(i),lenFeatures - sizeTime);
        
        if(balanced)
            % Picks the random indx to train
            M = idxClasses{i};
            p = randperm(length(M)); % Reshuffle their order randomly
            vecRandomPicksTrain{i} = M(p(1:vecNumImgs(i))); % Choose the first N of these
            vecRandomPicksTrain{i} = sort(vecRandomPicksTrain{i}); % Sort them
        end
    end
    
    % Creates the cell to prepare the data
    countTotal = 1;
    vecCountNumImgs = ones(lenClasses,1);
    for i = 1:lenFiles
        labels_result = load([videos_path '\' dirList{i} '\labels_result_' dirList{i} '.mat']);
        labels_result = labels_result.labels_result;
        partialLen = size(labels_result, 2);
        
        features = load([videos_path '\' dirList{i} '\features.mat']);
        features = features.F;
        
        for j = 1:partialLen
            label_id = labels_result(j).label;
            if(any(joined_labels==label_id))
                label_id = joined_labels(1);
            end
            
            if(balanced)
                
                picksThisLabelTrain = vecRandomPicksTrain{label_id};
                if(vecCountNumImgs(label_id) <= length(picksThisLabelTrain) && countTotal == picksThisLabelTrain(vecCountNumImgs(label_id)))
                    F{label_id}(vecCountNumImgs(label_id),:) = [features(j,(sizeTime+1):lenFeatures)];
                    vecCountNumImgs(label_id) = vecCountNumImgs(label_id) + 1;
                end
                
            else
                
                F{label_id}(vecCountNumImgs(label_id),:) = [features(j,(sizeTime+1):lenFeatures)];
                vecCountNumImgs(label_id) = vecCountNumImgs(label_id) + 1;
                
            end
           
            countTotal = countTotal + 1;
            
        end
    end
    
    
    if(strcmp(method, 'KNN'))
        
        Feat = [];
        L = [];% labels
        for i = 1:lenClasses
            Feat = [Feat; F{i}];
            L = [L; ones(size(F{i},1),1)*i];
        end

        %classifies
        trainedClassifiers = ClassificationKNN.fit(Feat,L,'NumNeighbors',numNearestNeighboursKNN);
        
        % Saves the result
        save([app_path '/KNN classifier/Combined Classifier/NPvsP+SP/classifier.mat'], 'trainedClassifiers');
        if(~silent)
            disp(' ');
            disp(['KNN classifier trained and saved.']);
        end
        
    elseif(strcmp(method, 'AdaBoost'))
        
        trainNorm = cell2struct(F', labels_cell, 1);
        % Trains the AdaBoost classifier
        trainedClassifiers = trainBOOST(false, trainNorm, numOfAdaBoostClassifiers, labels_cell, 'OneVsOne');

        % Saves the result
        save([app_path '/AdaBoost classifier/Combined Classifier/NPvsP+SP/classifier.mat'], 'trainedClassifiers');
        if(~silent)
            disp(' ');
            disp(['AdaBoost classifier trained and saved.']);
        end
    
    end
    
    if(~silent)
        toc
    end
    
end


% Loads the classes file
function loadClasses()
    global classes;
    global app_path;

    classes_path = app_path;
    
    file = [classes_path '/classesLabeling.mat'];
    if(exist(file, 'file'))
        data = load(file);
        classes = data.classes;
    end
end