% Extracts the features of the images
%%%
%   We MUST ALWAYS run first rescaleImages.m before loading this
%   extractFeatures.m script in order to have a better result when
%   extracting the features.
%   Afterwards we have to run extractEuclidDist.m right before
%   starting the Labeling process.
%%%

function extractFeatures()

    global path;
    global months;
    global maxDate; % stores the max value for each element in a date-time
    global havePosition; % indicates if we must include the Position (for cropped photos) in the features set
    
    months = {'Jan'; 'Feb'; 'Mar'; 'Apr'; 'May'; 'Jun'; 'Jul'; 'Aug'; 'Sep'; 'Oct'; 'Nov'; 'Dec'};
    % day month year hour minute second
    maxDate = {31; 12; 2030; 23; 59; 59};
    %path = 'images';
    path = '..\Labeling\Demo Labeling - WORKING COPY\Videos';
    folders_original = {'650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part1', '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part2', '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part3', '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part4','650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part5','Dishes images_renamed_1to100_slides-part1-part1', 'Dishes images_renamed_1to100_slides-part1-part2','Dishes images_renamed_1to100_slides-part2-part1','Dishes images_renamed_1to100_slides-part2-part2', 'EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part1','EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part2','EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part3','EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part4'}; 
    folders = {'650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part1_89x120', '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part2_89x120', '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part3_89x120', '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part4_89x120','650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part5_89x120','Dishes images_renamed_1to100_slides-part1-part1_89x120', 'Dishes images_renamed_1to100_slides-part1-part2_89x120','Dishes images_renamed_1to100_slides-part2-part1_89x120','Dishes images_renamed_1to100_slides-part2-part2_89x120', 'EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part1_89x120','EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part2_89x120','EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part3_89x120','EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part4_89x120'}; 
    havePosition = true; 
    
    
    
    len = length(folders);
    % for each folder with images (each day)
    for i = 1:len
        fileList = dir([path '/' folders{i} '/*.jpg']);
        fileList_original = dir([path '/' folders_original{i} '/*.jpg']);
        len2 = length(fileList);
        
        % Only for cropped photos
        if(havePosition)
            slides_data = load([path '/' folders_original{i} '/result_slide.mat']);
            slides_data = slides_data.result;
        end
        
        F = [];
        % for each image in this folder
        for j = 1:len2
            % we get its features
            if(havePosition)
                F = [F getFeatures([folders{i} '/' fileList(j).name], fileList_original(j).date, slides_data(j))];
            else
                F = [F getFeatures([folders{i} '/' fileList(j).name], fileList_original(j).date, false)];
            end
%             disp(['Folder ' folders{i} ' image ' fileList(j).name ' done: ' num2str(j) '/' num2str(len2)]);
            if(mod(j,100) == 0)
                disp(['Folder ' folders{i} ' done: ' num2str(j) '/' num2str(len2)]);
            end
        end
        F = F';
        save([path '/' folders{i} '/features.mat'], 'F');
        disp(['Features from images in folder ' folders{i} ' saved.']);
    end
    
end


%% Calculates the features for a given image with the specified date
% The format of the features is:
%   6 x Time + 3 x RGB + 81 x HOG + 4 x Position
function features = getFeatures(imgDir, date, slide)

    features = [];
    global path;
    global months;
    global maxDate;
    global havePosition;
    img = imread([path '/' imgDir]);
    
    % we get the desired format for the date
    date = regexp(date,' ','split');
    date = [regexp(date(1),'-','split') regexp(date(2),':','split')];
    found = false;
    i = 1;
    while(~found)
        if(months{i} == date{1}{2})
            found = true;
        end
        i = i+1;
    end
    date{1}(2) = {num2str(i-1)};
    
    
    %% We insert the first set of features, the ones describing the DATE
    % day, month, year, hour, minute, second
    count = 1;
    for i = 1:2
        for j = 1:3
%             features = [features; ((str2num(date{i}{j}) / maxDate{count}))];
            features = [features; 0];
            count = count+1;
        end
    end
    
    %% We get the features related to the COLOUR
    % R, G, B
    color = extractFeatureColor(img);
    for i = 1:3
        features = [features; (color(i)/255)];
    end
    
    %% We get the features related to the HOG gradient
    hog81 = HOGparam(rgb2gray(img), 3,3,9);
    
    features = vertcat(features, hog81);

    
    %% We get the position data if the photos were cropped
    if(havePosition)
        features = [features; slide.x/slide.maxW];
        features = [features; slide.y/slide.maxH];
        features = [features; slide.w/slide.maxW];
        features = [features; slide.h/slide.maxH];
    end
    
end
