
%% Balanced KNN classification by two steps:
%
%   STEP 1: No Plate vs (Plate + Semiplate)
%   STEP 2: Plate vs Semiplate
%
function unseen_labels = KNN_for_tree(uniqueLabels, seen_labels, seen_features, unseen_features)

    global join_labels;
    global numNearestNeighboursKNN;
    
    global classNoPlate;
    global classPlate;
    global classSemiplate;

    lenSeen = length(seen_labels);
    lenUnseen = size(unseen_features,1);
    unseen_labels = zeros(size(unseen_features,1), 1);
    
    %% NoPlate vs Semiplate + Plate
    
    % Gets the indexes of the element of each class
    count = zeros(2, 1);
    posElems = {};
    for i = 1:2
        posElems{i} = [];
    end
    for i = 1:lenSeen
        label = seen_labels(i);
        if(any(join_labels==label))
            label = join_labels(1);
        end
        
        count(label) = count(label) +1;
        posElems{label} = [posElems{label} i];
    end
    
    % All the seen_labels are No Plate
    if(count(2) == 0)
        unseen_labels = ones(size(unseen_features,1), 1) * classNoPlate.id;
    else
        
        % It only does the first classification if there is some No Plate
        if(count(1) ~= 0)
            
            % Balances the sets
            numPicks = min(count);
            chosen_features = [];
            chosen_labels = [];
            for i = 1:2
                % Picks the random indx to train
                M = posElems{i};
                p = randperm(length(M)); % Reshuffle their order randomly
                chosen_features = [chosen_features; seen_features(M(p(1:numPicks)), :)]; % Choose the first "numPicks" of these
                chosen_labels = [chosen_labels; ones(numPicks,1)*i];
            end

            % Classifies
            classifier = ClassificationKNN.fit(chosen_features,chosen_labels,'NumNeighbors',numNearestNeighboursKNN);
            [labels likelihood] = predict(classifier,unseen_features);


            % Calculates the resulting label for each image
            nextTest = [];
            for i = 1:length(labels)

                j = labels(i);
                % Stores the result
                if(j == classNoPlate.id) % No Plate
                    unseen_labels(i) = classNoPlate.id;
                elseif(j == 2) % Plate + Semiplate
                    nextTest = [nextTest; i];
                end

            end
        
        % If all the labels are Plate or Semiplate
        else
            nextTest = 1:size(unseen_features, 1);
        end


        % Gets the features of the images that we have to classify again
        next_unseen_features = zeros(length(nextTest), size(unseen_features, 2));
        for i = 1:length(nextTest)
            next_unseen_features(i,:) = unseen_features(nextTest(i),:);
        end



        %% Plate vs SemiPlate

        % Gets the indexes of the element of each class
        count = zeros(length(join_labels), 1);
        posElems = {};
        for i = 1:length(join_labels)
            posElems{i} = [];
        end
        for i = 1:lenSeen
            label = seen_labels(i);
            if(any(join_labels==label))
                label = label-1;

                count(label) = count(label) +1;
                posElems{label} = [posElems{label} i];
            end
        end

        % Balances the sets
        numPicks = min(count);
        
        % There isn't any sample of some of the labels
        if(count(1) == 0)
            
            unseen_labels(nextTest) = classSemiplate.id;
            
        elseif(count(2) == 0)
            
            unseen_labels(nextTest) = classPlate.id;
            
        else
            chosen_features = [];
            chosen_labels = [];
            for i = 1:length(join_labels)
                % Picks the random indx to train
                M = posElems{i};
                p = randperm(length(M)); % Reshuffle their order randomly
                chosen_features = [chosen_features; seen_features(M(p(1:numPicks)), :)]; % Choose the first "numPicks" of these
                chosen_labels = [chosen_labels; seen_labels(M(p(1:numPicks)))];
            end

            % Classifies
            classifier = ClassificationKNN.fit(chosen_features,chosen_labels,'NumNeighbors',numNearestNeighboursKNN);
            [labels likelihood] = predict(classifier,next_unseen_features);


            % Calculates the resulting label for each image
            for i = 1:length(labels)

                j = labels(i);
                % Stores the result
                if(j == classPlate.id) % Plate
                    unseen_labels(nextTest(i)) = classPlate.id;
                elseif(j == classSemiplate.id) % Semiplate
                    unseen_labels(nextTest(i)) = classSemiplate.id;
                end

            end
            
        end
        
    end

end