function jpeg_info = qva_create(study, log_file)
%qva_create Calculates the basic void jpg_info structure.
%
% INPUT:
%   study   -> The study struture.
%   log_file -> The filename of the log file to write the GTDExpander output.
%
% OUTPUT:
%   jpeg_info -> The jpeg_info struture.
%
%  Ex: 
%   jpeg_info = qva_create(study, log_file);
%   
% (c) MI group, Computer Vision Center, UAB, 2007
%


jpg_dir = study_jpg_path(study);
if exist(jpg_dir) == 0 
  jpeg_info = [];
  return
end

current_dir = pwd;

cd(jpg_dir);
files2     = dir('*.bmp');
num_frames = size(files2, 1);
vol = 0.0;

jpeg_info = repmat(struct('filename', (zeros(1, 256)), ...
                         'time', zeros(1,8), ...
                         'vol', vol), ...
                  [1, num_frames]); 

atras ='';
[frameIndex frameId frameTime]=getRAPIDFrameNumbers([study.video_path '/stream'],0,999999);
for i = 1:num_frames
    xx = sprintf('%d/%d', i, num_frames);
    fprintf('%s%s', atras, xx);

    % aadimos el filename
    str   = files2(i).name;
    jpeg_info(i).filename = str;

    % aadimos el time
    jpeg_info(i).time     = frameTime(i,:);
    
    jpeg_info(i).ID = frameId(i);

    
    atras = repmat(char(8), [1 size(xx,2)]);
end
fprintf('\n');



cd(current_dir);

