function [study, jpeg_info] = qva_create_all_NEW(study,gfhFile,gfdFile, smooth)
%qva_create_all Calculates the basic image features 
%
% INPUT:
%   study   -> The study struture.
%   gfhFile -> The .gfhFile filename.
%   gfdFile -> The .gfdFile filename.
%
% OUTPUT:
%   study             -> The study struture.
%   jpeg_info         -> The jpeg_info struture.
%
%
%  Ex: 
%   [study, jpeg_info] = qva_create_all(study,gfhFile,gfdFile);
%   
% (c) MI group, Computer Vision Center, UAB, 2010
%
    
modified = 0;
laps_modified = 0;

% load (or create) jpeg_info
jpeg_info = qva_load(study);
if isempty(jpeg_info) 
    jpeg_info = qva_create(study);
    modified = 1;
    if ( isempty(jpeg_info) ) 
       return;
    end
end


% %% Reverse ALC (Automatic Light Correction)
fprintf('---------------------------\n')
fprintf('\t\t Reversing ALC.....\n')
study=study_jpg_reverseALC(study,jpeg_info,gfhFile,gfdFile, smooth);
study_save(study);
 


% Load wrinkles file
load('parametersSlidingWindowWrinkles');

fprintf('\t\t Calculating basic features: vol, lap, area_blob, vol_blob_x_lap, minvol, inertia, lochomo...\n');
atras =''; 
last_blob = [];
distance = 1;

% compute basic feature for each frame
if(~qva_is_features_analyzed(jpeg_info))
 for i=study.thresholds(1):study.thresholds(2)
      xx = sprintf('%d/%d', i, study.thresholds(2));
      fprintf('%s%s', atras, xx);
      %get image from disk
      image = qva_get_frame(study, jpeg_info, i);
      %get normalized image using illumination model
      image_gray=normalize_image(image, study.model);
      % creat the sum of pixels in image
      jpeg_info(i).vol_NEW=qva_create_vol_NEW(image_gray);
      % Calculate the blob size using the lapalacian
      [jpeg_info(i).lap_blob_NEW, lap, lap_blob_unico]= qva_create_laps_NEW(image_gray);
      % Calculate the blob area
      [jpeg_info(i).area_blob_NEW, last_blob, distance]=qva_create_area_blob_NEW(image_gray, last_blob, distance);

      % Caculate the vol in the laplacian
      [jpeg_info(i).vol_blob_x_lap_NEW, jpeg_info(i).minvol_NEW] = qva_create_vol_blob_x_lap_NEW(lap, lap_blob_unico);
      % Caculate the textural features
      [jpeg_info(i).inertia_NEW, jpeg_info(i).lochomo_NEW] = qva_create_textural_features_NEW(image_gray);
      % Caculate the wrinkle features
      jpeg_info(i).wrinkle_score_NEW=qva_create_wrinkle_score_NEW(image_gray, areaMask, looktable);
       atras = repmat(char(8), [1 size(xx,2)]);
 end
end



% calculate vol_norm
fprintf('\t\t Calculating the video_normalization "vol_norm". "vol_norm_NEW"... \n');
if ( ~qva_is_normalized(jpeg_info) ) 
    jpeg_info = qva_normalize_NEW(study, jpeg_info);
    modified = 1;
end




% extract turbid feature
fprintf('\t\t Calculating the turbid features...\n');
if ( ~qva_is_turbid_features(study) ) 
    qva_create_turbid_features(study,jpeg_info);
    modified = 1;
end

% extract EMD feature
fprintf('\t\t Calculating the static features...\n');
if ( ~qva_is_static_features(study) ) 
    qva_create_static_features(study, jpeg_info);
    modified = 1;
end

fprintf('\t\t Saving the jpg_info...\n');
if ( modified~=0 || laps_modified~= 0 ) 
    qva_save(jpeg_info, study);
end


