function [Energy_16,Entropy_16,Inertia_16,Lochomo_16,Clussh_16,Cluspro_16] = qva_create_coocurrence_textural_features(a,mask)
%qva_create_texture_features Calculates the coocurrence matrix-based features.
%
% INPUT:
%   a   -> The image resized to 64x64.
%   mask -> The mask for the textural features.
%
% OUTPUT:
%   result -> The jpeg_info struture.
%   msg  -> A message in case of error.
%
%   This function creates 6 textural features:
%
%   Second order statistics from the co_occurence matrices:
%      Energy, Entropy, Inertia,Local Homogeneity,Cluster, Prominence
%      and Cluster shade.
%
%  Ex: 
%   [ result, msg ] = qva_create_texture_features(study, jpg_info);
%   
% (c) MI group, Computer Vision Center, UAB, 2007
%


format short g
ind_mask=find(mask==1);
vect=a(ind_mask);
w=[17 33 49 65 80 96 112 128 144 160 176 192 207 223 239 255];  % we use  16 gray levels
      % It fixes the size of the concurrence matrix [16x16], in this case 
                                                            
dim=size(w,2);
c=histeq(vect,dim);
c1=imadjust(c,[],[17/255 1]);
m2=mask;
m2(ind_mask)=c1;
cell=double(m2);
matrix=zeros(dim,dim);
matrh=qva_create_coocurrence_textural_features_mat1(cell,w,dim);
matrix_v=qva_create_coocurrence_textural_features_mat2(cell,w,dim);
matrix_ld=qva_create_coocurrence_textural_features_mat3(cell,w,dim);
matrix_rd=qva_create_coocurrence_textural_features_mat4(cell,w,dim);
matrix=1/4*(matrh+matrix_v+matrix_ld+matrix_rd);
s=sum(sum(matrix));
l=length(matrix);
mp=matrix./s;
wp=w;
energy=0;
entropy=0;
lochomo=0;
inertia=0;
correlation=0;
clussh=0;
cluspro=0;


mx=0;
my=0;
sx=0;
sy=0;
for i=1:l
    for j=1:l
        if mp(i,j)~=0;
            entropy=entropy+mp(i,j)*log(mp(i,j));
            energy=energy+mp(i,j)^2;
            lochomo=lochomo+mp(i,j)/(1+(wp(i)-wp(j))^2);
            inertia=inertia+(wp(i)-wp(j))^2*mp(i,j);
            mx=mx+wp(i)*mp(i,j);
            my=my+wp(j)*mp(i,j);
        end
    end
end
for i=1:l
     for j=1:l
         sx=sx+(wp(i)-mx)^2*mp(i,j);
         sy=sy+(wp(j)-my)^2*mp(i,j);
         clussh=clussh+((wp(i)-mx)+(wp(j)-my))^3*mp(i,j);
         cluspro=cluspro+((wp(i)-mx)+(wp(j)-my))^4*mp(i,j);
     end
 end
 for i=1:l
     for j=1:l
         correlation=correlation+(wp(i)-mx)*(wp(j)-my)*mp(i,j)/(sqrt(sx)*sqrt(sy));
     end
 end
Energy_16=energy;
Entropy_16=-entropy;
Inertia_16=inertia;
Lochomo_16=lochomo;
Correlation_16=correlation;
Clussh_16=clussh;
Cluspro_16=cluspro;

