function [Inertia_16,Lochomo_16] = qva_create_coocurrence_textural_features_NEW(a,mask)
%qva_create_texture_features Calculates the coocurrence matrix-based features.
%
% INPUT:
%   a   -> The image resized to 64x64.
%   mask -> The mask for the textural features.
%
% OUTPUT:
%   Inertia_16 ->
%   Lochomo_16  ->
%
%   This function creates 2 textural features:
%
%   Second order statistics from the co_occurence matrices:
%     Inertia,Local Homogeneity
%
%  Ex:
%   [ result, msg ] = qva_create_texture_features(study, jpg_info);
%
% (c) MI group, Computer Vision Center, UAB, 2007
%


format short g
ind_mask=find(mask==1);
vect=a(ind_mask);
w=[17 33 49 65 80 96 112 128 144 160 176 192 207 223 239 255];  % we use  16 gray levels
% It fixes the size of the concurrence matrix [16x16], in this case

dim=size(w,2);
c=histeq(vect,dim);
c1=imadjust(c,[],[17/255 1]);
m2=mask;
m2(ind_mask)=c1;
cell=double(m2);
matrix=zeros(dim,dim);
matrh=qva_create_coocurrence_textural_features_mat1(cell,w,dim);
matrix_v=qva_create_coocurrence_textural_features_mat2(cell,w,dim);
matrix_ld=qva_create_coocurrence_textural_features_mat3(cell,w,dim);
matrix_rd=qva_create_coocurrence_textural_features_mat4(cell,w,dim);
matrix=1/4*(matrh+matrix_v+matrix_ld+matrix_rd);
s=sum(sum(matrix));
l=length(matrix);
mp=matrix./s;
wp=w;


lochomo=0;
inertia=0;

mx=0;
my=0;

for i=1:l
    for j=1:l
        if mp(i,j)~=0;
                       
            lochomo=lochomo+mp(i,j)/(1+(wp(i)-wp(j))^2);
            inertia=inertia+(wp(i)-wp(j))^2*mp(i,j);
            mx=mx+wp(i)*mp(i,j);
            my=my+wp(j)*mp(i,j);
        end
    end
end

Inertia_16=inertia;
Lochomo_16=lochomo;

