function [lap_NEW, lap2, lap2_blob_unico]= qva_create_laps_NEW(image_gray)
%qva_create_laps_NEW calculate blob size using laplacian
%
% INPUT:
%   image_gray   -> The study struture.
%
% OUTPUT:
%   lap_NEW         -> blob size
%   lap2            -> lab filter 
%   lap2_blob_unico -> blob segmentation image
%
%  Ex: 
%   [study, jpeg_info] = qva_create_all(study,gfhFile,gfdFile);
%   
% (c) MI group, Computer Vision Center, UAB, 2010

mask = qva_get_mask(64, 64, 0.63);
image  = imresize(image_gray, [128 128], 'bicubic');
h      = fspecial('log', [64 64], 12); 
lap    = filter2(h, image);
lap2   = imresize(lap, [64 64], 'bicubic');

% blob detection
laplacianas_blobs = lap2 > 0 & mask;
  
% blob labels
labels = bwlabel(laplacianas_blobs, 8);
    
% obtaing the maximum size blob
bw             = labels; 
num_etiquetas  = max(bw(:));
max_vol  = -1000000;
max_blob = 1;
for j=1:num_etiquetas
        b = (bw == j);
        m = max(lap2(b));
        if m > max_vol 
            max_vol  = m;
            max_blob = j;
        end 
end
lap2_blob_unico = (labels==max_blob); 
lap_NEW = sum(lap2_blob_unico(:));
end