function resample_findings_indexes = qva_create_resample_findings_indexes(study)
%qva_create_resample_findings_indexes Calculates resampled findings.
%
% INPUT:
%   study   -> The study struture.
%
% OUTPUT:
%   resample_findings_indexes -> The findings resmapled.
%
%  This function associates each of the expert findings to one and only one
%  of the resampled indexes. Since the output of the system is always in
%  terms of resampled indexes, in order to calculate the accuracy, we
%  associate all the expert indexes to one of the resampled indexes.
%
%
%  Ex: 
%   resample_findings_indexes = qva_create_resample_findings_indexes(study);
%   
% (c) MI group, Computer Vision Center, UAB, 2007
%

resample_indexes = study_get_resample_indexes(study);
findings_indexes = study_get_findings_indexes(study);


% we associate the expert findings (which are not resampled)
% to one and only one resampled frame
if ~isempty(findings_indexes)
    
    x = findings_indexes;
    c = resample_indexes';
    % dist2 function 
    [ndata, dimx] = size(x);
    [ncentres, dimc] = size(c);
    if dimx ~= dimc
        error('Data dimension does not match dimension of centres')
    end
    n2 = (ones(ncentres, 1) * sum((x.^2)', 1))' + ...
    ones(ndata, 1) * sum((c.^2)',1) - ...
    2.*(x*(c'));
    % Rounding errors occasionally cause negative entries in n2
    if any(any(n2<0))
     n2(n2<0) = 0;
    end
    % end dist2 function
    [d_min, d_min_ind] = min(n2');
    resample_findings_indexes = resample_indexes(d_min_ind);
else
    resample_findings_indexes = [];
end
