function [ result, msg ] = qva_create_texture_features(study, jpg_info)
%qva_create_texture_features Calculates the textural features for the cascade.
%
% INPUT:
%   study   -> The study struture.
%   jpeg_info -> The jpeg_info struture.
%
% OUTPUT:
%   result -> The jpeg_info struture.
%   msg  -> A message in case of error.
%
%   This function creates 6 textural features:
%
%   1) Second order statistics from the co_occurence matrices:
%      Energy, Entropy, Inertia,Local Homogeneity,Cluster, Prominence
%      and Cluster shade
%   2) First order statistics from the image histogram:
%      Mean,std,skeweness and kurtosis
%   3) The 18th bin histogram of the LBPs and the 4 moments
%      from the histogram (might not be correct the way ...it
%      needs to reconsidered
%
%  Ex: 
%   [ result, msg ] = qva_create_texture_features(study, jpg_info);
%   
% (c) MI group, Computer Vision Center, UAB, 2007
%




vector=nchoosek([0:4 0 0 1 1 2 2 3 3 4 4],3);

% Loads the masc image
mask = qva_get_textural_mask(64, 64);


% We check whether the thresholds include the full study
[ub1, ub2] = study_get_limits(study);
num = size(jpg_info,2);
if ub1 == -1
    ub1 = 1;
    ub2 = num;
end

    % NUEVA_CASCADA_LABEL
    % 6./ normalization para las textural features
    load norm_mod;
    
fprintf('--- Textural features ---\n');
atras ='';
for i=ub1:ub2
    xx = sprintf('%d/%d', i, ub2);
    fprintf('%s%s', atras, xx);

    
    % We load the image
    im = study_get_frame(study, jpg_info(i).filename );
    
    

        a=rgb2gray(im);
%     a = normalize_image(im, norm_mod);
    b=imresize(a,[64 64]);

    % We calculate the coocurrence textural features
    [Energy_16,Entropy_16,Inertia_16,Lochomo_16,Clush_16,Cluspro_16] =  qva_create_coocurrence_textural_features(b,mask);
    jpg_info(i).inertia=Inertia_16; 
    jpg_info(i).lochomo=Lochomo_16;
    
    
    
    % NUEVA_CASCADA_LABEL
%     a=rgb2gray(im);
    a = normalize_image(im, norm_mod);
    b=imresize(a,[64 64]);

    % We calculate the coocurrence textural features
    [Energy_16,Entropy_16,Inertia_16,Lochomo_16,Clush_16,Cluspro_16] =  qva_create_coocurrence_textural_features(b,mask);
    jpg_info(i).inertia_COR=Inertia_16; 
    jpg_info(i).lochomo_COR=Lochomo_16;

    


    
    atras = repmat(char(8), [1 size(xx,2)]);
   
   
end


result = jpg_info;
msg='';


