function [wrinkle_score] = qva_create_wrinkle_score_NEW(image_gray, areaMask, looktable)
%qva_create_wrinkle_score_NEW wrinkle score
%
% INPUT:
%   image_gray   -> gray image
%   areaMask   ->    mask
%   looktable  ->   lookup table with features probabilies
%
% OUTPUT:
%   wrinkle_score     -> wrinkle score
%
%
%  Ex:
%   [study, jpeg_info] = qva_create_all(study,gfhFile,gfdFile);
%
% (c) MI group, Computer Vision Center, UAB, 2010
%

% get structre tensor information
[Lprime, bwo, vx_second, vy_second]=Wrinkles_Score_Sliding_Window_norm_inmask_NEW(image_gray,areaMask);

%calculate orientation histogram
featTest=Wrinkles_Score_Sliding_Window_features_histograms_windows(Lprime,vx_second,vy_second,bwo);


% create the feature vector for the wrinkle classification
featureVector=[];
for t=1:size(featTest,1)
    for tt=1:size(featTest,2)
        featureVector=[featureVector ;featTest{t,tt}];
    end
end
featureVector(:,37)=sum(featureVector(:,1:8)');
featureVector(:,38)=sum(featureVector(:,9:16)');
featureVector(:,39)=sum(featureVector(:,17:24)');
featureVector(:,40)=sum(featureVector(:,25:32)');
featureVector(:,41)=sum(featureVector(:,1:32)');
featureVector(:,42)=abs(sum(featureVector(:,1:8)')-sum(featureVector(:,17:24)'));
featureVector(:,43)=abs(sum(featureVector(:,9:16)')-sum(featureVector(:,25:32)'));

% calcualte the image score probability using lookup table with values
% probabilites of each feature
probTest=zeros(size(featureVector));
for j=1:size(featureVector,2)
    ind=round(featureVector(:,j)*2)+1;
    probTest(:,j)=looktable(j,ind);
end
scoresT=sum(log(probTest'));
wrinkle_score=max(scoresT(:));

end