function [index1, index2] = qva_find_limits(jpg_info, time_start, time_end)
%qva_find_limits Finds the start and end indices for the studio evaluation.
%
% INPUT:
%   jpg_info   -> The jpg_info struture.
%   time_start -> The time of the first frame to be analyzed.
%   time_end   -> The time of the last frame to be analyzed.
%
% OUTPUT:
%   index1 -> The index of the first frame to be analyzed.
%   index2 -> The index of the last frame to be analyzed.
%
%  Ex: 
%    [index1, index2] = qva_find_limits(jpg_info, time_start, time_end);
%   
% (c) MI group, Computer Vision Center, UAB, 2007
%


num_frames = length(jpg_info);
tim = [{jpg_info(:).time}'];
ind_1 = find(strcmp(tim, time_start));
ind_2 = find(strcmp(tim, time_end));
if ~isempty(ind_1) 
    index1 = ind_1(1);
else
    index1 = 1;
end

if ~isempty(ind_2) 
    index2 = ind_2(1);
else
    index2 = num_frames;
end


