function mask = qva_get_textural_mask(resx, resy, size)
%qva_get_textural_mask Load the mask used for the texture analysis.
%
% INPUT:
%   resx   -> The horizontal resolution of the mask.
%   resy   -> The horizontal resolution of the mask.
%   size -> The size of the mask (not needed currently).
%
% OUTPUT:
%   mask             -> The  mask used for the texture analysis.
%
%  Ex: 
%  mask = qva_get_textural_mask(resx, resy, size);
%   
% (c) MI group, Computer Vision Center, UAB, 2007
%

current_dir = pwd;
p = qva_module_path;
cd(p);
m = imread('qva_textural_mask.png');
m2 = imresize(m, [resx resy], 'bicubic');
mask = uint8(m2 == 255);
cd(current_dir);
return

% alternative version without the need of a special mask file:
% -> \see qva_get_mask.m
% \return a circular mask of given resolution
%
% x^2/a^2+y^2/b^2 = size
% a = w/2
% b = h/2
%if ~exist('size')
%    size = 1;
%end
%[mx, my] = meshgrid(1:resx, 1:resy);
%cx = resx/2-0.5;
%cy = resy/2-0.5;
%mx = mx-cx-1;
%my = my-cy-1;
%mx = mx./cx;
%my = my./cy;
%
%m = mx.*mx+my.*my;
%mask = m<size;
