function result = qva_normalize(study, jpg_info)
%qva_normalize Adds the jpg_info matrix with normalized intensity.
%
% INPUT:
%   study   -> The study struture.
%   jpeg_info         -> The jpeg_info struture.
%
% OUTPUT:
%   result   -> The jpeg_info struture.       
%
%  In order to calculate the normalized intensity of the i-frame, we take
%  [i-N:i+N] and we calculate the normalized intesity of these images. This
%  value is substracted from every pixel of the i-frame, and stores into
%  jpg_info(i).vol_norm. 
%
%  Ex: 
%   result = qva_normalize(study, jpg_info);
%   
% (c) MI group, Computer Vision Center, UAB, 2007
%
if  qva_is_normalized(jpg_info) == 1
  result = jpg_info;
  return
end

[limits(1), limits(2)] = study_get_limits(study);
num_frames = length([limits(1):limits(2)]);
%num_frames = size(jpg_info, 2);
N = 5;

%
% For the inner frames
%

fprintf('Normalizing %i frames...\n', num_frames);
atras = '';
for i=limits(1)+N:limits(2)-N
    x = sprintf('%d/%d', i, limits(2));
    fprintf('%s%s', atras, x);
%     
%     imag_mean              = sum([jpg_info(i-N:i+N).vol])/ (2*N+1);
%     jpg_info(i).vol_norm = jpg_info(i).vol - imag_mean;

     % NUEVA_CASCADA_LABEL:
    imag_mean_NEW              = sum([jpg_info(i-N:i+N).vol_NEW])/ (2*N+1);
    jpg_info(i).vol_norm_NEW = jpg_info(i).vol_NEW - imag_mean_NEW;
    

    atras = repmat(char(8), [1 size(x,2)]);
end
%
% For the 2 x N of the extrems, we assign the arbitrary value '0'.

for i=1:N
    jpg_info(limits(1) + i -1).vol_norm_NEW   = 0;
    jpg_info(limits(2) - i +1).vol_norm_NEW   = 0;
end


result = jpg_info;

