function result = study_assert(study)
%  STUDY_ASSERT asserts the existence of the main fields in the STUDY structure.
%  
%   INPUT:
%       study -> The study structure 
%   
%   OUTPUT:
%       result -> 1 if all the fields are defined; 0 otherwise
%
result = 0;
if ( nargin <1 ) 
    return;
end;

% the folder where all studies are located. a full path (e.g. f:/intes)
if ~isfield(study, 'data_path') 
  return;
end;

% the folder where all expanded jpgs are located. a full path (e.g. f:/intes_videos)
% also, the used grml file for this study (the avi files plus the gtd file are not needed any more afterwards).
if ~isfield(study, 'media_path') 
  return;
end;

% the folder where the study is, relating to the data_root folder. relative path name, cannot be '.'
if ~isfield(study, 'name') 
  return;
end;


% the boundary clinical times for the video analysis are extracted from the grml file. they need not to be stored
% the boundary indexes for the video frames are created from the clinical times above plus the enumeration of the jpg_info file.
% they are stored like: [12345 67890]
% 
if ~isfield(study, 'thresholds') 
  return;
end;
% check the dimension of the thresholds
if size(study.thresholds, 2) ~=2 && size(study.thresholds, 1) ~=1 
  return;
end;
% check the threshold integrity
if study.thresholds(1)>study.thresholds(2)
  return;
end;

result = 1;