function result = study_bmp_rename(study)
% STUDY_BMP_RENAME renames the given bmps in the folder.
%
%   INPUT:
%       study -> The study structure. 
%
%   OUTPUT:
%       result -> 0 if the parameters are incorrec or there are no bmp to rename
%
%   Example:
%     param study the studio structure
%     return 0 if the parameters are incorrect
%              or there are no jpgs to rename
%     return 1 if the video has been expanded
%   Examples:
%     study_jpg_rename(study)
%
%
%   Rename the file using alwasys 6 figures in the ID_000000->ID_999999
%   Creates a file 'rename.log' containing the output of the renaming
%   Creates a file 'renamed_ok.txt' after successful renaming of the file
%   Both files are created in the jpg directory.

if study_assert(study) == 0 
  result = 0;
  return
end

jpg_dir = study_jpg_path(study);

rename_marker = sprintf('%s/renamed_ok.txt', jpg_dir);

% check whether files have been renamed already
if exist(rename_marker) == 2 
  fprintf('\t\t BMP files already re-named\n');
  result = 1;
  return
end

log_file = 'rename.log';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 4) Renaming files. Le ponemos un formato para que el ID_ tenga
%    6 cifras ID_000000->ID_999999
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
current_dir = pwd;
cd(jpg_dir);       % ya estamos en el directorio de los ficheros .jpg
files2     = dir('*.bmp');
num_frames = size(files2, 1);
if num_frames == 0 
  result = 0;
  cd(current_dir);
  return
end

fid = fopen('jpgs.bat', 'w');

for i = 1:num_frames
    str = files2(i).name;
    % localizamos el ID
    [pathstr_s, name_s, ext_s, versn_s] = fileparts(str);
    str1 = sprintf('%d', str2double(name_s));
    str2 = sprintf('%06d', str2double(name_s));
    filename = strrep(str, str1, str2);
    % renombramos el fichero
    x = sprintf('rename "%s" "%s"\n', str, filename);
    fprintf(fid, '%s', x);
end
fclose(fid);

dos(sprintf('jpgs.bat > %s', log_file));
dos('del jpgs.bat');

fid = fopen('renamed_ok.txt', 'w');
fprintf(fid, 'all jpegs renamed.');
fclose(fid);

cd(current_dir)

result = 1;
