function result = study_create(name, data_path, media_path, grml_file, limits)
% STUDY_CREATE creates an empty study structure with the given paths.
%
%   INPUT:
%       name       -> The study name. 
%       data_path  -> The path for storing the resulting study structure.
%       media_path -> The path for storing the media files.
%       grml_file  -> The file of the findings annotated by the experts.
%       limits     -> The study time thresholds.
%
%   OUTPUT:
%       result -> The study structure; [] if the study could not be created.
%
%  The resulting structure has the following fields:
%
%         study.name                      ->  The study name.
%         study.data_path                 ->  The data path.
%         study.media_path                ->  The media path.
%         study.time_thresholds           ->  The study time limits.
%         study.thresholds                ->  The study thresholds in frame indexes.
%         study.output_indexes            ->  The system findings.
%         study.tunnel_indexes            ->  The system tunel indexes.
%         study.expert_turbid_indexes     ->  The turbid indexes 
%         study.classify                  ->  Flag: 1 means that the study has 
%                                             already been classified.
%         study.reverseALC                ->  Flag: means that the
%                                             jpeg files was converted with the ALC
%
% Example:
%           study = study_create(name, data_path, media_path, grml_file,
%           limits);
%

result = [];

study.name = name;
study.data_path = data_path;
study.media_path = media_path;
study.time_thresholds = limits;
study.thresholds = [-1 0];
study.output_indexes  =  [];
study.tunnel_indexes  =  [];
study.expert_turbid_indexes    =  [];
study.classify = [];
study.reverseALC               =  0;
study.model =  [];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1) Create the media directory of the study
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if exist('grml_file') == 0 
    disp(['Cannot access grml file' grml_file '.']);
    return;
end

study_path = study_get_study_path(study);

% creates the directory to store data
if exist(study_path) == 0 
  mkdir(study_path);  
  if exist(study_path)  
      disp(['Created directory ' study_path '.']);
  else
      disp(['Cannot create directory ' study_path '.']);
      result = [];
      return;
  end
end


result = study;
fprintf('\t\t STUDY %s created\n', study.name);