function [indexes, result, msg] = study_grml2index(study, jpg_info, filenamepath_grml)
%  STUDY_GRML2INDEX provides the indexes corresponding to the findings in a .grml file.
%  
%   INPUT:
%       study              -> The study structure.
%       jpg_info           -> The jpg_info structure.
%       filenamepath_grml  -> The full path and name of the .grml file. 
%   
%   OUTPUT:
%       indexes -> The frame indexes corresponding to the finidngs in the .grml file. 
%       result  -> 0 if the file could no be accessed; 1 elsewhere.
%       msg     -> A string containing information about the result flag.
%
% Example:
%       [indexes, result, msg] = study_grml2index(study, jpg_info, ...
%                                filenamepath_grml)
%


if exist('filenamepath_grml') == 0 
    if strcmp(study_get_grml_file(study), ''); 
            result = 0;
            msg = 'Cannot access grml file: Not in the function parameters and not in STUDY structure.';
            return;
    else
        filenamepath_grml = sprintf('%s/%s', study_get_study_path(study), study_get_grml_file(study));
        msg = '';
        result = 1;
    end
end
   






% The IDs of all the frames
IDs = [jpg_info.ID]';

% We open the .grml
    xx = filenamepath_grml;
    fprintf('----------Buscando los indices de los findings en...   %s\n', xx);
    FILE = fopen(xx, 'r');
    a             = fread(FILE);
    fclose(FILE);
    a = char(a');  % convertimos de ascii a caracter
    b             = findstr('frameId="', a)';   % el comienzo de cada ID
    num_findings  = size(b,1);
    for i=1:num_findings
        t1 =  b(i) + 9;                           % la primera cifra del ID
        t2 = findstr('"', a(b(i)+9:b(i)+9+6));    % el indice de la segunda "
        findings(i) = str2num(a(t1:t1 + t2 -2));       % Un vector columna con todos los IDs de los findings
    end
    findings = findings';
num_findings = size(findings, 1);
atras = '';
for i=1:num_findings
    xxxx = sprintf('%d/%d', i, num_findings);
    fprintf('%s%s', atras, xxxx);
    dumm = find(IDs == findings(i));
    if(isempty(dumm))
        while(isempty(dumm))
             dumm = find(IDs == findings(i)+1);   
        end
    end
    index(i,1) = dumm;           % el vector de indices jpg_info correspondientes a las contracciones
    atras = repmat(char(8), [1 size(xxxx,2)]);
end
findings_index = index; 
indexes = findings_index;
result =1;
msg = '';

