function [result, study] = study_jpg_expand(study, input_path, gtd_file, gtd_expander_path, log_file)
% STUDY_JPG_EXPAND expands the Given movie into the bmp files.
%
%   INPUT:
%       study             -> The study structure. 
%       input_path        -> The location of the gtd_file.
%       gtd_file          -> The name of the gtd_file.
%       gtd_expander_path -> The path to the expander application gtdexpander.exe
%       log_file          -> The path and filename to the log output of the
%                            expander.
%   OUTPUT:
%       result -> '' if the paremeters are not correct; 1 if the video was succesfuly
%                 expanded.
%   Examples:
%     study_jpg_expand(study, '/intes_input', 'GT_AL_04 Dec 02_C1-R.gtd', ...
%                      '.', 'mylog.log')
%
%     study_jpg_expand('/intes_output/my_studio', '/intes_input', ...
%                      'GT_AL_04 Dec 02_C1-R.gtd', '.', 'NUL')
%     expands the studio and discards the log.
%


if study_assert(study) == 0 
  result = 0;
  return
end

% Check gtd video file
[pathstr, gtd_file_name, ext, versn] = fileparts(gtd_file);
if strcmp(study.name,gtd_file_name) ~= 1
    disp(['Study "' study.name '" must have the same name as the GTD file name "' gtd_file_name '".']);
    result = 0;
    return;
end

% get folder name to store video images
jpg_base = study_jpg_base(study);
jpg_dir = study_jpg_path(study);

% create the folder to store video images
if exist(jpg_base) == 0 
  mkdir(jpg_base);  
  if exist(jpg_base)  
      disp(['Created directory ' jpg_base '.']);
  else
      disp(['Cannot create directory ' jpg_base '.']);
      result = 0;
      return;
  end
end


p_log_file =  log_file;

% we read the avi file
loc_cd  = cd;
avi_dir_temp = [pathstr '/stream' ];
cd(avi_dir_temp);
aaa = dir('*.avi');
avi_filename_tmp = aaa.name;
av_inf = aviinfo(avi_filename_tmp);
n_frames = av_inf.NumFrames;
cd(loc_cd);


if exist([jpg_dir '\rename.log']) ~= 2 
  mkdir(jpg_dir) ;
  xx = sprintf('\t\t Starting expansion of video %s ...\n', gtd_file);
  disp(xx);

    
  %extract all video frames
  folder=pwd;
  cd(gtd_expander_path);
  n_frames=9999999;
  GetRAPIDFrames(avi_dir_temp,0,n_frames,jpg_dir,0);
  cd(folder)
  result=0;
  
  
  if result == 0 
    xx = sprintf('\t\t Finished expansion of video. Log in %s', p_log_file);
    disp(xx);
    result = 1;
  else
    xx = sprintf('\t\t Video could not be expanded! Log in %s', p_log_file);
    disp(xx);www
    result = 0;
    return;
  end
else
  xx = sprintf('\t\t Video already expanded in %s', jpg_dir);
  disp(xx)
end

if study_jpg_rename(study) == 0 
  xx = sprintf('\t\t Video images could not be renamed! Log in %s', p_log_file);
  disp(xx);
  result = 0;  
  return; 
end


% create jpeg_info strucure
jpeg_info = qva_load(study);
if isempty(jpeg_info) 
    jpeg_info = qva_create(study);
    modified = 1;
    if ( isempty(jpeg_info) ) 
       return;
    end
end


% We calculate the features ONLY within the limits
limits = study_get_time_limits(study);
[istart, iend] = qva_find_limits(jpeg_info, limits{1}, limits{2});
study = study_set_limits(study, istart, iend);



% Convert bmp images to mat files 
[result, study,jpeg_info] = study_bmp_2_mat(study,jpeg_info);
if result == 0 
  xx = sprintf('\t\t Video images could not be converted to mat! Log in %s', p_log_file);
  disp(xx);
  result = 0;  
  return; 
end

%save study and jpeg_info into disk
study_save(study);
qva_save(jpeg_info, study);
result = 1;
fprintf('\t\t VIDEO completely expanded\n')