function [study jpeg_info] = study_jpg_reverseALC(study,jpeg_info,gfh_file,gfd_file, smooth)
% STUDY_JPG_REVERSEALC rewrite images with reversing the ALC
%
%   INPUT:
%       study             -> The study structure.
%       jpeg_info         -> The jpeg_file strucure.
%       gfh_file          -> The location of the gfh_file.
%       gtd_file          -> The location of the gtd_file.
%       smooth            -> indicates the smooth options
%   OUTPUT:
%       result -> '' if the paremeters are not correct; 1 if the video was succesfuly
%                 expanded.
%   Examples:
%     study_jpg_reverseALC(study)
%

% get image video path
jpg_path = study_jpg_path(study);

if exist([jpg_path '\reverseALC_ok.txt']) ~= 2
    
    
    % GET CAPSULE INFO
    GFH=read_ALC(gfh_file);
    GFD1=read_motility_gfd(gfd_file);
    [ColMat1 ColMat2 CapsuleType CapsuleConfig] =read_gfhParameters(gfh_file);
    
    %FILTER:
    h=fspecial('disk',5);
    im=zeros(256,256); % norm
    
    atras = '';
    num_frames=study.thresholds(2)-study.thresholds(1)+1;
    for index= study.thresholds(1):study.thresholds(2)
        
        xx = sprintf('%d/%d', index, size(jpeg_info,2));
        fprintf('%s%s', atras, xx);
        
        % get image with ALC correction
        image=qva_get_frame_illumination_correction_SB2(study, jpeg_info, index,GFD1,GFH,ColMat1,CapsuleType,CapsuleConfig);
        
        impath = sprintf('%s/%s', jpg_path, jpeg_info(index).filename );
        
        % apply mask to the image
        mask = imread('mask_SB2.bmp');
        maskF=[];
        maskF(:,:,1)=mask;
        maskF(:,:,2)=mask;
        maskF(:,:,3)=mask;
        maskF=uint8(maskF);
        image=image-maskF;
        
        if(smooth==1)
            image=uint8(imfilter(image,h));
        elseif (smooth==2)
            image=get_filtred_frame_NLMEANS(image);
        end
        %data for illumination model
        im_gray = rgb2gray(image);
        im=im+double(im_gray); % nor
        
        save(impath,'image');
       
        atras = repmat(char(8), [1 size(xx,2)]);
        
    end
    
    % create illumination model
    im_final=im /(num_frames-1); % nor
    im_final=medfilt2(im_final, [10 10]); % nor
    max_im_final=max(max(im_final)); % nor
    study.model=im_final / max_im_final; % nor
    
    fid = fopen([jpg_path '\reverseALC_ok.txt'], 'w');
    fprintf(fid, 'Reverse ALC Ok.');
    fclose(fid);
    
    fprintf('\t\t VIDEO completely rewritted\n')
end