% Applies the Large Margin Nearest Neighbours algorythm for the already seen
% samples in cluster with id c_id and splits the seen and unseen ones in 
% new clusters. 
%
% IN
% c_id: id of the cluster
%
% OUT
% elems: Ids for all the elements in the cluster
% cluster: Id of the cluster that each elem belongs to
% original_features: original features from this elements
function [elems cluster original_features] = apply_LMNN(c_id, nClusters)

    global C;
    global numNearestNeighboursLMNN;

    % Gets the cluster idx
    found = false;
    i = 1;
    while(~found)
        if(C(i).id == c_id)
            found = true;
            c_id = i;
        end
        i = i+1;
    end
    


    %% We get the seen elements
    seen_elems = C(c_id).seen_idx;
    lenSeen = length(seen_elems);
    seen_elems_pos = [];
    for i = 1:lenSeen
        seen_elems_pos = [seen_elems_pos find(C(c_id).elements_id==seen_elems(i))];
    end
    % We get all the features of the seen elements
    seen_features = C(c_id).features(seen_elems_pos, :);
    seen_labels = C(c_id).seen_labels;
    uniqueLabels = unique(seen_labels);
    
    
    %% We get the unseen elements
    unseen_elems = setdiff(C(c_id).elements_id, C(c_id).seen_idx);
    lenUnseen = length(unseen_elems);
    unseen_elems_pos = [];
    for i = 1:lenUnseen
        unseen_elems_pos = [unseen_elems_pos find(C(c_id).elements_id==unseen_elems(i))];
    end
    % We get the features of the unseen elements
    unseen_features = C(c_id).features(unseen_elems_pos, :);
    
    
    %% KNN classification for the unseen samples
    unseen_labels = KNN_for_tree(uniqueLabels, seen_labels, seen_features, unseen_features);
    
    
    %% Balancing for LMNN (which applies PCA first)
    elems = [seen_elems unseen_elems];
    all_features = [seen_features; unseen_features];
    original_features = all_features;
    all_labels = [seen_labels; unseen_labels];
    
    count = zeros(length(uniqueLabels), 1);
    posElems = {};
    for i = 1:length(uniqueLabels)
        posElems{i} = [];
    end
    for i = 1:(lenSeen+lenUnseen)
        pos = find(uniqueLabels==all_labels(i));
        count(pos) = count(pos) +1;
        posElems{pos} = [posElems{pos} i];
    end
    numPicks = min(count);
    chosen_features = [];
    chosen_labels = [];
    for i = 1:length(uniqueLabels)
        % Picks the random indx to train
        M = posElems{i};
        p = randperm(length(M)); % Reshuffle their order randomly
        chosen_features = [chosen_features; all_features(M(p(1:numPicks)), :)]; % Choose the first "numPicks" of these
        chosen_labels = [chosen_labels; all_labels(M(p(1:numPicks)))];
    end

    %% LMNN
    LMNN_ok = true;
    if(length(unique(chosen_labels)) > 1)
        if(numPicks <= numNearestNeighboursLMNN && numPicks > 1)
            [L, Det] = lmnn2(chosen_features', chosen_labels', numPicks-1, 'outdim', 6, 'quiet', 1, 'maxiter', 100);
            transformed_features = all_features * L';
        elseif(numPicks > numNearestNeighboursLMNN)
            [L, Det] = lmnn2(chosen_features', chosen_labels', numNearestNeighboursLMNN, 'outdim', 6, 'quiet', 1, 'maxiter', 100);
            transformed_features = all_features * L';
        else
            LMNN_ok = false;
        end
    else
        LMNN_ok = false;
    end
    
    %% KMeans clustering
    if(LMNN_ok && ~isempty(transformed_features))  
        [cluster, centroid] = kmeans(transformed_features, nClusters, 'emptyaction', 'singleton');
    else
        cluster = all_labels;
        % If any of them was semiplate we put it in the plate group
        if(nClusters < 3)
            cluster(find(cluster==3)) = 2;
        end
    end

    
end

