%%
%   Checks if the AdaBoost Online learner is already created and if so, it
%   classifies all the loaded images to initialy discard some of them.
function checkOnlineLearner()
    %% Variables initialization
    
    global folder_path;
    global classes;
    global C;
    global proposed_labels;
    global numOfImgs;
    global numOfPrototypes;
    
    global classifierType;
    global onlineLearnerType;
    global usingPrototypes;
    
    global th_No_Plate;
    global th_Plate;
    global th_Semiplate;
    global classNoPlate;
    global classPlate;
    global classSemiplate;
    
    global idOnlineLearner;
    
    addpath('classifiers');

    % Loads the classifier
    if(classifierType == 0) % AdaBoost
        if(onlineLearnerType == 1) % Single Classificator
            path_classifier = {'../AdaBoost classifier/Single Classifier/classifier.mat'};
        elseif(onlineLearnerType == 2) % Combined Classificator
            path_classifier = {'../AdaBoost classifier/Combined Classifier/NPvsP+SP/classifier.mat','../AdaBoost classifier/Combined Classifier/PvsSP/classifier.mat'};
        end
    elseif(classifierType == 1) % KNN
        if(onlineLearnerType == 1) % Single Classificator
            path_classifier = {'../KNN classifier/Single Classifier/classifier.mat'};
        elseif(onlineLearnerType == 2) % Combined Classificator
            path_classifier = {'../KNN classifier/Combined Classifier/NPvsP+SP/classifier.mat','../KNN classifier/Combined Classifier/PvsSP/classifier.mat'};
        end
    end

    classifiers = {};
    for i = 1:length(path_classifier)
        classifiers{i} = load(path_classifier{i});
        classifiers{i} = classifiers{i}.trainedClassifiers;
    end
    labels_cell = {}; % Stores the different labels of our images

    
    % Gets a cell with all the classes names
    lenClasses = length(classes);
    for i = 1:lenClasses
        labels_cell(i) = {['label_' num2str(classes(i).id)]};
    end

    %% Images classification
    
    % Loads the features file
    % We eliminate the features related to the Time (6 components)
    sizeTime = 6;
    features = load([folder_path '\features.mat']);
    features = features.F;
    lenFeatures = size(features, 2);
    testImgs = [];
    
    % If we are using prototypes
    if(usingPrototypes)
        num = numOfImgs - numOfPrototypes;
    else
        num = numOfImgs;
    end
    
    for i = 1:num
        if(C.reliability(i) ~= 1)
            testImgs = [testImgs i];
        end
    end
    
    % We get the features of the images that we have to classify
    F = zeros(length(testImgs), lenFeatures - sizeTime);
    for i = 1:length(testImgs)
        F(i,:) = features(testImgs(i),(sizeTime+1):lenFeatures);
    end

    
    if(classifierType == 0) % AdaBoost
        if(onlineLearnerType == 1) % Single Classificator
            
            AdaBoost_SingleClassifier(F, labels_cell, classifiers{1}, testImgs, lenClasses);
        
        elseif(onlineLearnerType == 2) % Combined Classificator
            
            AdaBoost_CombinedClassifier(F, labels_cell, classifiers{1}, classifiers{2}, testImgs, lenClasses);
            
        end
    elseif(classifierType == 1) % KNN
        if(onlineLearnerType == 1) % Single Classificator
            
            KNN_SingleClassifier(F, classifiers{1}, testImgs);
            
        elseif(onlineLearnerType == 2) % Combined Classificator
            
            KNN_CombinedClassifier(F, classifiers{1}, classifiers{2}, testImgs);
            
        end
    end

    
    
end