%%
% Divides each of the seen_C (C in this function) in K (numClasses) parts 
% using the Fisher-LDA algorythm
function [C_div]=divide_partition_das_LDA(C, labels, C_new)

    global numOfImgs;
    global nClusters;
    global activeLearnerType;
    
    C_div=[];
    ids = get_id_clusters_LDA(C_new);

    % Applies Linear Discriminant Analysis to predict the distribution
    % in clusters for the elements in C
    if(activeLearnerType == 2)
        [elems predict_clusters features] = apply_LDA(C.id, nClusters);
    % Applies Large Margin Nearest Neighbours
    elseif(activeLearnerType == 3)
        [elems predict_clusters features] = apply_LMNN(C.id, nClusters);
    end

    for j = 1:nClusters
        [C_tmp]=initialize_arbol(ids(j));

        indexes = find(predict_clusters==j);
        
        C_tmp.elements_id = elems(indexes);
        C_tmp.features = features(indexes,:);

        % We only continue if there is some element in the cluster
        if(length(C_tmp.elements_id) > 0)
            
            C_tmp.seen_idx=intersect(C.seen_idx,C_tmp.elements_id);
            C_tmp.seen_labels=labels(C_tmp.seen_idx)+1;

            C_tmp.weight=length(setdiff(C_tmp.elements_id, C_tmp.seen_idx)) / numOfImgs;


            C_tmp.classificationMethod = zeros(length(C_tmp.elements_id),1);

            % Gets the reliability information if it exists for this cluster
            if(C.checkReliability)
                C_tmp.checkReliability = 1;

                C_tmp.reliability = zeros(length(C_tmp.elements_id),1);
                C_tmp.reliableLabels = zeros(length(C_tmp.elements_id),1);
                C_tmp.likelihood = zeros(length(C_tmp.elements_id),1);

                i = 1;
                while(i <= length(C_tmp.elements_id))
                    l = find(C.elements_id==C_tmp.elements_id(i));

                    C_tmp.reliableLabels(i) = C.reliableLabels(l);
                    C_tmp.classificationMethod(i) = C.classificationMethod(l);
                    C_tmp.reliability(i) = C.reliability(l);
                    C_tmp.likelihood(i) = C.likelihood(l);

                    i=i+1;
                end
            end 

            C_div=[C_div C_tmp];
        end
        
    end


end