%%  Checks if the image foundXY(k) is the same that the image foundXY(j)
%   given that the format of the foundXY matrix is:
%       [ xk yk wk hk]
%       [ xj yj wj hj]
%   And considering that the must have at least the percentatge
%   'similarityRate' (value from 0 to 1) in common.
function same = sameFace(foundXY, k, j)

    global simmilarityRate;

    same = false;
    
    if( doOverlap( foundXY(:,k),foundXY(:,j) ) )

        left = isFaceALeft( foundXY(:,k),foundXY(:,j) );
        right = isFaceARight( foundXY(:,k),foundXY(:,j) );
        up = isFaceAUp( foundXY(:,k),foundXY(:,j) );
        down = isFaceADown( foundXY(:,k),foundXY(:,j) );
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % One inside the other
        if(left && right && up && down) % faceJ is in faceK
            same = true;
        elseif(~left && ~right && ~up && ~down) % faceK is in faceJ
            same = true;
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Diagonal (sharing corners)
        elseif(left && up)
            w = (foundXY(1,k) + foundXY(3,k)) - foundXY(1,j);
            h = (foundXY(2,j) + foundXY(4,j)) - foundXY(2,k);
        elseif(right && up)
            w = (foundXY(1,j) + foundXY(3,j)) - foundXY(1,k);
            h = (foundXY(2,j) + foundXY(4,j)) - foundXY(2,k);
        elseif(left && down)
            w = (foundXY(1,k) + foundXY(3,k)) - foundXY(1,j);
            h = (foundXY(2,k) + foundXY(4,k)) - foundXY(2,j);
        elseif(left && down)
            w = (foundXY(1,j) + foundXY(3,j)) - foundXY(1,k);
            h = (foundXY(2,k) + foundXY(4,k)) - foundXY(2,j);
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Center and cardinal positions
        elseif(up)
            if(left && right)% faceK bigger than faceJ
                w = foundXY(3,j);
                h = (foundXY(2,j) + foundXY(4,j)) - foundXY(2,k);
            else
                w = foundXY(3,k);
                h = (foundXY(2,j) + foundXY(4,j)) - foundXY(2,k);
            end
        elseif(down)
            if(left && right)% faceK bigger than faceJ
                w = foundXY(3,j);
                h = (foundXY(2,k) + foundXY(4,k)) - foundXY(2,j);
            else
                w = foundXY(3,k);
                h = (foundXY(2,k) + foundXY(4,k)) - foundXY(2,j);
            end
        elseif(left)
            if(left && right)% faceK bigger than faceJ
                w = (foundXY(1,k) + foundXY(3,k)) - foundXY(1,j);
                h = foundXY(4,j);
            else
                w = (foundXY(1,k) + foundXY(3,k)) - foundXY(1,j);
                h = foundXY(4,k);
            end
        elseif(right)
            if(left && right)% faceK bigger than faceJ
                w = (foundXY(1,j) + foundXY(3,j)) - foundXY(1,k);
                h = foundXY(4,j);
            else
                w = (foundXY(1,j) + foundXY(3,j)) - foundXY(1,k);
                h = foundXY(4,k);
            end
        end
        if(~same)
            sub_area = w*h;
            k_area = foundXY(3,k) * foundXY(4,k);
            j_area = foundXY(3,j) * foundXY(4,j);
            if( sub_area >= (k_area * simmilarityRate) || sub_area >= (j_area * simmilarityRate))
                same = true;
            end
        end
    end
end
    

% Checks if the pair of faces overlap
function x = doOverlap(faceA, faceB)

    faceAleft = faceA(1) < ( faceB(1) + faceB(3) );
    faceAright = ( faceA(1) + faceA(3) ) > faceB(1);
    faceAdown = faceA(2) < ( faceB(2) + faceB(4) );
    faceAup = ( faceA(2) + faceA(4) ) > faceB(2);

    if(faceAleft && faceAright && faceAup && faceAdown)
        x = true;
    else
        x = false;
    end
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The following functions compare if the faceA is more to the corresponding
% side compared to faceB's same side
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function x = isFaceAUp(faceA, faceB)
    if( (faceA(2)+faceA(4)) > (faceB(2)+faceB(4)) )
        x = true;
    else
        x = false;
    end
end

function x = isFaceADown(faceA, faceB)
    if(faceA(2) < faceB(2))
        x = true;
    else
        x = false;
    end
end

function x = isFaceALeft(faceA, faceB)
    if(faceA(1) < faceB(1))
        x = true;
    else
        x = false;
    end
end

function x = isFaceARight(faceA, faceB)
    if( (faceA(1)+faceA(3)) > (faceB(1)+faceB(3)) )
        x = true;
    else
        x = false;
    end
end
