
function analyseOLPerformance()
    
    load('test_OL_data.mat');
    test_name = {'[1] KNN'; '[2] AdaBoost'};
    
    colors = [  1  0  0;
                0.2000  1.0000  0.2000;
                0.9686  0.6824  0.1294  ];
    
    times = [];
    for i = 1:length(test_OL_data)
        times = [times; test_OL_data(i).avg_time];
    end
    
    %% Time bars graphic
    figure
    f = bar(times);
    bar_child=get(f,'Children');
    set(bar_child,'CData',1:length(times));

    % Reduce the size of the axis so that all the labels fit in the figure.
    pos = get(gca,'Position');
    set(gca,'Position',[pos(1), 0.2, pos(3) .7])

    Xt = 1:length(times);
    Xl = [0 length(times)];

    ax = axis; % Current axis limits
    axis(axis); % Set the axis limit modes (e.g. XLimMode) to manual
    Yl = ax(3:4); % Y-axis limits

    t = text(Xt,Yl(1)*ones(1,length(Xt)), test_name);
    set(t,'HorizontalAlignment','right','VerticalAlignment','top','Rotation',45, 'fontsize', 8);

    % Remove the default labels
    set(gca,'XTickLabel','');

    title('Average classification time for each Online Learner');
    ylabel('Average time (seconds)');

    saveas(f, ['Plot Results/Average Time Online Learners'], 'jpg');
    
    
    %% Predictions bars
    
    x = test_name;
    y = [];
    for i = 1:length(test_OL_data)
        y = [y; test_OL_data(i).avg_predicted];
    end
    
    % Creates the figure
    fig_h = figure;
    bar_h = bar(1:length(x), y);
   
    
    % Set the X-Tick locations
    Xt = 1:length(x);
    Xl = [0 length(x)+1.5];
    set(gca,'XTick',Xt,'XLim',Xl);

    ax = axis; % Current axis limits
    axis(axis); % Set the axis limit modes (e.g. XLimMode) to manual
    Yl = ax(3:4); % Y-axis limits
    
    % Place the text labels
    t = text(Xt,Yl(1)*ones(1,length(Xt)), x);
    set(t,'HorizontalAlignment','center','VerticalAlignment','top','Rotation',0);
    
    % Remove the default labels
    set(gca,'XTickLabel','');
    
    % Sets the color to each bar
	for i = 1:length(bar_h)
        set(bar_h(i),'facecolor',colors(i,:))
    end
    
    title('Predicted Labels Per Classifier');
    legend('No Plate','Plate','Semiplate');
    
    saveas(fig_h, ['Plot Results/Predicted Labels Per Classifier'], 'jpg');
    
    %% Predictions evolution
    
    NP = zeros(length(test_OL_data), length(test_OL_data(1).set_data)+1);
    P = zeros(length(test_OL_data), length(test_OL_data(1).set_data)+1);
    SP = zeros(length(test_OL_data), length(test_OL_data(1).set_data)+1);
    for i = 1:length(test_OL_data)
        for j = 1:length(test_OL_data(1).set_data)
            p = test_OL_data(i).set_data(j).predicted;
            NP(i, j+1) = p(1);
            P(i, j+1) = p(2);
            SP(i, j+1) = p(3);
        end
    end
    
    f = figure;
    plot(1:size(NP,2), NP(1,:), '-rs', 'Color', 'r');
    hold all;
    plot(1:size(NP,2), NP(2,:), '-.rs', 'Color', 'r');
    
    ylabel('Number of Predicted Labels');
    xlabel('Set ID');
    legend('KNN No Plate','AdaBoost No Plate');
    title('Predicted Labels Evolution No Plate');
    
    saveas(f, ['Plot Results/Predicted Labels Evolution No Plate'], 'jpg');
    
    f2 = figure;
    plot(1:size(NP,2), P(1,:), '-rs', 'Color', 'g');
    hold all;
    plot(1:size(NP,2), P(2,:), '-.rs', 'Color', 'g');
    hold all;
    plot(1:size(NP,2), SP(1,:), '-rs', 'Color', 'y');
    hold all;
    plot(1:size(NP,2), SP(2,:), '-.rs', 'Color', 'y');

    ylabel('Number of Predicted Labels');
    xlabel('Set ID');
    legend('KNN Plate','AdaBoost Plate','KNN Semiplate','AdaBoost Semiplate');
    title('Predicted Labels Evolution Plate & Semiplate');
    
    saveas(f2, ['Plot Results/Predicted Labels Evolution Plate & Semiplate'], 'jpg');
    
end