
% Does a complete simulation of the labeling of a group of sets in order,
% given some common parameters and accumulating the trees' data.
function mainForestSimulation()

    global HANDLES;
    global HANDLES_FIN;
    global folder_path;
    global setsPath;
    addpath(pwd);
    
    pathh = regexp(mfilename('fullpath'), '\', 'split');
    pathh = pathh(1:end-3); auxpath = pathh{1};
    for i = 2:length(pathh)
        auxpath = [auxpath '\' pathh{i}]; 
    end
    addpath([auxpath '\AdaBoost and KNN']);
    warning off;
    
    % Used for multiple test simulation
    numTests = 3;

    %% Data structures initialization
    
    % Data stored for each single set labeled
    labeling_data = struct('num_clicks_array', {}, 'time', {}, ...
        'num_elements', {}, 'set_name', {}, 'C_normal', {}, ...
        'C_pure', {}, 'labels_result', {}, 'features', {}, ...
        'time_classifier', {}, 'count_predicted', {});
    
    % Data stored for a whole forest simulation
    forest_simulation_data = struct('test_type', {}, 'labeling_data', {}, ...
        'activeLearnerType', {}, 'onlineLearnerType', {}, ...
        'classifierType', {}, 'prototypesType', {}, 'num_clusters', {}, ...
        'usingPrototypes', {}, 'usingVariance', {}, ...
        'usingOnlineLearner', {}, 'k_KNN', {}, 'k_LMNN', {}, ...
        'threshold_var', {}, 'th_LH_No_Plate', {}, ...
        'th_LH_Plate_Semiplate', {}, 'th_LH_Plate', {}, 'th_LH_Semiplate', {});
    
    
    %% Parameters
    
    % {1 = Single sets test, 2 = JoinDays test, 3 = JoinAll test}
    forest_simulation_data(1).test_type = 1;
    
    % ActiveLearner type
    % { 1 = Hierarchical Cluster Tree, 2 = Linear Discriminant Analysis Tree,
    %   3 = Large Margin Nearest Neighbours }
    forest_simulation_data(1).activeLearnerType = 1;
    % Type of classifier used {0 = AdaBoost, 1 = KNN}
    forest_simulation_data(1).classifierType = 1;
    % OnlineLearner type 
    % {1 = Single Classifier, 2 = Combined Classifier}
    forest_simulation_data(1).onlineLearnerType = 2;
    % Type of prototypes {1 = One Per Class, 2 = One Per Leaf (form previously classified tree)}
    forest_simulation_data(1).prototypesType = 1;
    
    % KNN, LMNN and KMeans
    forest_simulation_data(1).k_KNN = 15;
    forest_simulation_data(1).k_LMNN = 7;
    forest_simulation_data(1).num_clusters = 2;
    
    % Additional preprocessing data used
    forest_simulation_data(1).usingPrototypes = false;
    forest_simulation_data(1).usingVariance = false;
    forest_simulation_data(1).threshold_var = 1500;
    forest_simulation_data(1).usingOnlineLearner = false;
    
    % Threshold to consider that the onlineLearner can be trusted
    % KNN
    forest_simulation_data(1).th_LH_No_Plate = 0.7;
    forest_simulation_data(1).th_LH_Plate_Semiplate = 0.7;
    forest_simulation_data(1).th_LH_Plate = 0.9;
    forest_simulation_data(1).th_LH_Semiplate = 0.8;
    % AdaBoost
%     forest_simulation_data(1).th_LH_No_Plate = 0.075;
%     forest_simulation_data(1).th_LH_Plate_Semiplate = 0.075;
%     forest_simulation_data(1).th_LH_Plate = 0.075;
%     forest_simulation_data(1).th_LH_Semiplate = 0.075;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END PARAMETERS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Ordered sets selected for the simulation
    setsPath = '..\..\Labeling\Demo Labeling - WORKING COPY';
    
    % All sets test
    if(forest_simulation_data(1).test_type == 1)
        sets = {
            'Dishes images_renamed_1to100_slides-part1-part1_89x120'; 'Dishes images_renamed_1to100_slides-part1-part2_89x120'; 'Dishes images_renamed_1to100_slides-part2-part1_89x120'; 'Dishes images_renamed_1to100_slides-part2-part2_89x120'; ...
            '0BC25B01-7420-DD20-A1C8-3B2BD6C87CB0_3to62_slides-part1_89x120'; '0BC25B01-7420-DD20-A1C8-3B2BD6C87CB0_3to62_slides-part2_89x120'; '0BC25B01-7420-DD20-A1C8-3B2BD6C87CB0_3to62_slides-part3_89x120'; ...
            '6FD1B048-A2F2-4CAB-1EFE-266503F59CD3_81to120_slides-part1_89x120'; '6FD1B048-A2F2-4CAB-1EFE-266503F59CD3_81to120_slides-part2_89x120'; ...
            '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part1_89x120'; '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part2_89x120'; '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part3_89x120'; '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part4_89x120'; '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides-part5_89x120'; ...
            'D165DFFA-B41D-26BC-4C16-BFB23F981BE8_3783to3868_slides-part1_89x120'; 'D165DFFA-B41D-26BC-4C16-BFB23F981BE8_3783to3868_slides-part2_89x120'; 'D165DFFA-B41D-26BC-4C16-BFB23F981BE8_3783to3868_slides-part3_89x120'; ...
            'EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part1_89x120'; 'EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part2_89x120'; 'EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part3_89x120'; 'EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides-part4_89x120'; ...
            'FD214597-9360-9CA1-9393-914D9B7BB726_3844to3903_slides-part1_89x120'; 'FD214597-9360-9CA1-9393-914D9B7BB726_3844to3903_slides-part2_89x120'; 'FD214597-9360-9CA1-9393-914D9B7BB726_3844to3903_slides-part3_89x120'
            };
    elseif(forest_simulation_data(1).test_type == 2)
        sets = {
            'Dishes images_renamed_1to100_slides_89x120'; ...
            '0BC25B01-7420-DD20-A1C8-3B2BD6C87CB0_3to62_slides_89x120'; ...
            '6FD1B048-A2F2-4CAB-1EFE-266503F59CD3_81to120_slides_89x120'; ...
            '650EA48B-AB7B-4BA5-2FA1-34F3D1B3CE9D_11to91_slides_89x120'; ...
            'D165DFFA-B41D-26BC-4C16-BFB23F981BE8_3783to3868_slides_89x120'; ...
            'EE6B5EA5-9ABF-32DA-9709-AAFEB23BB51E_150to350_slides_89x120'; ...
            'FD214597-9360-9CA1-9393-914D9B7BB726_3844to3903_slides_89x120'
            };
    elseif(forest_simulation_data(1).test_type == 3)
        sets = {'All Folders_89x120'};
    end
    
    
    %% Repeats the tests alternating for each different option set
    for test_i = 1:numTests
        % Reset structures
        % Data stored for each single set labeled
        labeling_data = struct('num_clicks_array', {}, 'time', {}, ...
            'num_elements', {}, 'set_name', {}, 'C_normal', {}, ...
            'C_pure', {}, 'labels_result', {}, 'features', {});
        
        %% Parameters for each different option set
%         if(mod(j, 3) == 0) % OnePerLeaf prototypes
%             forest_simulation_data(1).usingPrototypes = true;
%             forest_simulation_data(1).prototypesType = 2;
%         elseif(mod(j, 3) == 1) % No prototypes
%             forest_simulation_data(1).usingPrototypes = false;
%         elseif(mod(j, 3) == 2) % OnePerClass prototypes
%             forest_simulation_data(1).usingPrototypes = true;
%             forest_simulation_data(1).prototypesType = 1;
%         end
        
        %% Sets parameters for the first simulation and runs it
        cd '..\..\Labeling\Demo Labeling - WORKING COPY\stable';
        run gui_intestinal_labeling;

        %% Does the first simulation
        setParametersSimulation(forest_simulation_data(1), true);
        folder_path = ['..\Videos\' sets{1}];
        disp(['Starting labeling ' sets{1} '  1/' num2str(length(sets))]);
        LoadVideo_Callback('', '', HANDLES);
        close(HANDLES_FIN.figure1);
        labeling_data = saveData(labeling_data, sets{1});

        %% Does the rest of the simulations
        setParametersSimulation(forest_simulation_data(1), false);
        for i = 2:length(sets)

            sets_train = {}; 
            for j = 1:(i-1)
                sets_train{j} = sets{j};
            end
            trainClassifiers(sets_train, forest_simulation_data(1));
            folder_path = ['..\Videos\' sets{i}];
            disp(['Starting labeling ' sets{i} '  ' num2str(i) '/' num2str(length(sets))]);
            LoadVideo_Callback('', '', HANDLES);
            close(HANDLES_FIN.figure1);
            labeling_data = saveData(labeling_data, sets{i});

        end
        close(HANDLES.figure1);

        %% Saves final data
        cd '..\..\..\Training-Test Analysis\Forest Labeler Simulation';
        forest_simulation_data(1).labeling_data = labeling_data;
        forest_simulation_data = forest_simulation_data(1);
        results = dir('Results');
        results = results(3:end);
        name = sprintf('%03d', length(results)+1);
        mkdir(['Results\' name]);
        save(['Results\' name '\forest_simulation_data.mat'], 'forest_simulation_data');

        disp(' ');
        disp(' ');
        disp('Forest Simulation FINISHED.');
        disp(' ');
        
        %% Send email
%         myaddress = 'mark.bs.1991@gmail.com';
%         mypassword = '';
% 
%         setpref('Internet','E_mail',myaddress);
%         setpref('Internet','SMTP_Server','smtp.gmail.com');
%         setpref('Internet','SMTP_Username',myaddress);
%         setpref('Internet','SMTP_Password',mypassword);
% 
%         props = java.lang.System.getProperties;
%         props.setProperty('mail.smtp.auth','true');
%         props.setProperty('mail.smtp.socketFactory.class', ...
%                           'javax.net.ssl.SSLSocketFactory');
%         props.setProperty('mail.smtp.socketFactory.port','465');
% 
%         sendmail(myaddress, ['Test finished ' num2str(test_i) '/' num2str(numTests)], 'Test finished');
        
        
    end
    
    warning on;
end


