
% Sets the parameters to the corresponding global variables for the forest
% simulation. 
%
% IN:
% params: forest_simulation_data struct with the params of the simulation.
% first_set: If false we set the parameteres in 'params', else we have
%            to disable the OnlineLearner and the Prototypes.
function setParametersSimulation(params, first_set)
    
    % ActiveLearner type
    % { 1 = Hierarchical Cluster Tree, 2 = Linear Discriminant Analysis Tree,
    %   3 = Large Margin Nearest Neighbours }
    global activeLearnerType;
    activeLearnerType = params.activeLearnerType;
    % Type of classifier used {0 = AdaBoost, 1 = KNN}
    global classifierType;
    classifierType = params.classifierType;
    % OnlineLearner type 
    % {1 = Single Classifier, 2 = Combined Classifier}
    global onlineLearnerType;
    onlineLearnerType = params.onlineLearnerType;
    % Type of prototypes {1 = One Per Class, 2 = One Per Leaf (form previously classified tree)}
    global prototypesType;
    prototypesType = params.prototypesType;

    % KNN, LMNN and KMeans
    global numNearestNeighboursKNN;
    numNearestNeighboursKNN = params.k_KNN;
    global numNearestNeighboursLMNN;
    numNearestNeighboursLMNN = params.k_LMNN;
    global nClusters;
    nClusters = params.num_clusters;

    % Additional preprocessing data used
    global usingPrototypes;
    global usingOnlineLearner;
    if(first_set)
        usingPrototypes = false;
        usingOnlineLearner = false;
    else
        usingPrototypes = params.usingPrototypes;
        usingOnlineLearner = params.usingOnlineLearner;
    end
    global usingVariance;
    usingVariance = params.usingVariance;
    % Threshold used for the variance check (if variance < threshold --> no plate)
    global threshold_var;
    threshold_var = params.threshold_var;

    % Threshold to consider that the onlineLearner can be trusted
    global th_No_Plate;
    global th_Plate_Semiplate;
    global th_Plate;
    global th_Semiplate;
    % Thresholds KNN
    th_No_Plate = params.th_LH_No_Plate;
    th_Plate_Semiplate = params.th_LH_Plate_Semiplate;
    th_Plate = params.th_LH_Plate;
    th_Semiplate = params.th_LH_Semiplate;

    % Says if the labeling will be authomatically simpulated
    global simulate;
    simulate = true;
    global simulationMode;
    % {1 = quick , 2 = slow (showing label changes) }
    simulationMode = 1;
    % Silences the simulation process
    global silent;
    silent = true;
    
end