function analyseResults_3classes()
    
    % Loads the classes info
    ids = {'No Plate', 'Plate', 'Semi-plate'};
    numGroundTruth = [1536 147 2330];
    rounds = 1000;

    % Loads the test results
    margins = load('../AdaBoost/margins_1vs2_1vs3_2vs3_1000rounds.mat');
    margins = margins.margins;


    % Calculates the resulting label for each image
    results = zeros(size(margins));
    labels = zeros(size(margins,1),1);
    for i = 1:size(margins,1)
        if(margins(i,1) > 0) % Class1 vs Class2
            results(i,1) = results(i,1) + margins(i,1);
        else
            results(i,2) = results(i,2) + abs(margins(i,1));
        end
        if(margins(i,2) > 0) % Class1 vs Class3
            results(i,1) = results(i,1) + margins(i,2);
        else
            results(i,3) = results(i,3) + abs(margins(i,2));
        end
        if(margins(i,3) > 0) % Class2 vs Class3
            results(i,2) = results(i,2) + margins(i,3);
        else
            results(i,3) = results(i,3) + abs(margins(i,3));
        end
        [c, j] = max(results(i,:));
        labels(i) = j;
    end

    % Calculates TP, FP and FN
    countFP = zeros(3,1);
    countTP = zeros(3,1);
    countFN = zeros(3,1);
    countTN = zeros(3,1);
    specificity = zeros(3,1);
    sensitivity = zeros(3,1);

    for i = 1:sum(numGroundTruth)

        if(i <= numGroundTruth(1)) % No Plate
            if(labels(i) == 1)
                countTP(1) = countTP(1) + 1;
            else
                countFP(labels(i)) = countTP(labels(i)) + 1;
            end
        elseif(i <= (numGroundTruth(1)+numGroundTruth(2))) % Plate
            if(labels(i) == 2)
                countTP(2) = countTP(2) + 1;
            else
                countFP(labels(i)) = countTP(labels(i)) + 1;
            end
        elseif(i <= (numGroundTruth(1)+numGroundTruth(2)+numGroundTruth(3))) % Semi Plate
            if(labels(i) == 3)
                countTP(3) = countTP(3) + 1;
            else
                countFP(labels(i)) = countTP(labels(i)) + 1;
            end
        end

    end
    
    % Calculates FN, TN, specificity and sensistivity
    for i = 1:3
        countFN(i) = numGroundTruth(i) - countTP(i);
        countTN(i) = sum(numGroundTruth) - (countTP(i) + countFN(i) + countFP(i));
        specificity(i) = countTP(i)/(countTP(i)+countFN(i));
        sensitivity(i) = countTN(i)/(countTN(i)+countFP(i));
    end


    % Displays the result in text format
    for i = 1:3
        disp(['[Class ' num2str(i) '] Total: ' num2str(numGroundTruth(i)) ', TP: ' num2str(countTP(i)) ', FN: ' num2str(countFN(i)) ', FP: ' num2str(countFP(i)) ', TN: ' num2str(countTN(i))]);
        disp(['          ' 'Specificity: ' num2str(specificity(i)) ', Sensitivity: ' num2str(sensitivity(i))]);
        disp(' ');
    end
    

    % Displays the result in a figure
    showFigure(ids, numGroundTruth, countTP', countFN', countFP', rounds);

end


% Displays a figure to see the results of the test
function showFigure(names, num, tp, fn, fp, rounds)

    colors = [  0.2706  0.6157  0.8078;
                0.2000  1.0000  0.2000;
                0.8000  0.2000  0;
                0.9686  0.6824  0.1294  ];

    x = names;
    y = [num; tp; fn; fp]';

    % Creates the figure
    fig_h = figure;
    bar_h = bar(1:length(x), y);
   
    
    % Set the X-Tick locations
    Xt = 1:length(x);
    Xl = [0 length(x)+1];
    set(gca,'XTick',Xt,'XLim',Xl);

    ax = axis; % Current axis limits
    axis(axis); % Set the axis limit modes (e.g. XLimMode) to manual
    Yl = ax(3:4); % Y-axis limits
    
    % Place the text labels
    t = text(Xt,Yl(1)*ones(1,length(Xt)), x);
    set(t,'HorizontalAlignment','center','VerticalAlignment','top','Rotation',0);
    
    % Remove the default labels
    set(gca,'XTickLabel','');
    
    % Sets the color to each bar
	for i = 1:length(bar_h)
        set(bar_h(i),'facecolor',colors(i,:))
    end
    
    legend('Total','TP','FN','FP');
    title(['AdaBoost rounds: ' num2str(rounds)]);

end
