function [data, labels, clusters] = syntheticTestGenerator(nSeeds, samplesPerSeed, dim, sigma, nClasses)
    
%     [data, labels] = syntheticTestGenerator(10, 400, 94, 0.05, 3);

    
    seeds = rand(nSeeds,dim);
    
    % Generates normally distributed random samples
    data = [];
    for i = 1:nSeeds
        data = [data; normrnd(repmat(seeds(i,:), samplesPerSeed, 1), sigma, samplesPerSeed, dim)];
    end


    % Normalizes the result between 0 and 1
    MIN = min(min(data));
    data = data+abs(MIN);
    MAX = max(max(data));
    data = data./MAX;
    
    
    % Assigns a random class to each group
    gPerClass = round(nSeeds/nClasses);
    groups = randperm(nSeeds);
    labels = zeros(nSeeds*samplesPerSeed,1);
    for i = 1:nClasses
        thisG = (i-1)*gPerClass+1 : i*gPerClass;
        if(i == nClasses)
            thisG = (i-1)*gPerClass+1 : nSeeds;
        end
        for j = thisG
            init = (groups(j)-1)*samplesPerSeed+1;
            fin = groups(j)*samplesPerSeed;
            labels(init:fin) = ones(samplesPerSeed, 1)*i;
        end
    end
    
    
%     % Shows the data in 2D
%     fig = figure;
%     gscatter(data(:,1), data(:,2), labels, 'rgymb','o');
%     legend('X', 'Y', 'Z');
    
    
    
    % Kmeans
    [clusters, centroid] = kmeans(data, nSeeds, 'emptyaction', 'singleton');
    
end

