
% Saves a folder with an image with high likelihood (KNN) and its
% neighbours, and the same for an image with low likelihood.
function getNeighbours(numClasses, F_train, F, F_t, numNeighbours, likelihood, vecRandomPicks, vecRandomPicksTrain, ntest, save_path, dirList, format)
    
    disp('Getting nearest neighbours...');
    disp(' ');

    %% Gets the sample with highest and lowest likelihood
    foundHigh = false;
    foundLow = false;
    lowLH = 1;
    lowLHidx = 0;
    highLH = 0;
    highLHidx = 0;
    len = size(likelihood, 1);
    rand = randi(len-1);
    i = rand+1;
    while((~foundHigh || ~foundLow) && i ~= rand)
        high = max(likelihood(i,:));
        if(high > highLH)
            if(high == 1)
                foundHigh = true;
            end
            highLH = high;
            highLHidx = i;
        elseif(high < lowLH)
            if(high == (ceil(numNeighbours/numClasses)/numNeighbours))
                foundLow = true;
            end
            lowLH = high;
            lowLHidx = i;
        end
        
        i = i+1;
        if(i > len)
            i = 1;
        end
    end
    
    %% Gets the neighbours' indices of those samples and their label
    F_test = [F_t(highLHidx, :); F_t(lowLHidx,:)];
    idx = knnsearch(F, F_test, 'K', numNeighbours);
    
    
    % Gets the labels and the absolute indices of the neighbours
    labels = zeros(2, numNeighbours);
    
    for i = 1:numNeighbours
        acumLength = 0;
        for j = 1:numClasses
            picksThisLabel = vecRandomPicksTrain{j};
            basePos = acumLength;
            acumLength = acumLength + length(F_train{j});
            
            if(labels(1,i) == 0 && idx(1,i) <= acumLength)
                labels(1,i) = j;
                idx(1,i) = picksThisLabel(idx(1,i) - basePos);
            end
            if(labels(2,i) == 0 && idx(2,i) <= acumLength)
                labels(2,i) = j;
                idx(2,i) = picksThisLabel(idx(2,i) - basePos);
            end   
        end
    end
    
    [idx(1,:) original_1] = sort(idx(1,:));
    [idx(2,:) original_2] = sort(idx(2,:));
    
    % Resorts the labels
    auxLabels = zeros(numNeighbours,1);
    for i = 1:numNeighbours
        auxLabels(i) = labels(1, original_1(i));
    end
    labels(1,:) = auxLabels;
    auxLabels = zeros(numNeighbours,1);
    for i = 1:numNeighbours
        auxLabels(i) = labels(2, original_2(i));
    end
    labels(2,:) = auxLabels;
    
    % Gets the labels of our low and high LH samples
    labelHigh = round(mean(labels(1,:)));
    labelLow = round(mean(labels(2,:)));
    
    % Gets the absolute indices of our low and high LH samples
    idxPassed = 0;
    for i = 1:numClasses
        picksThisLabel = vecRandomPicks{i};
        
        if(highLHidx > idxPassed && highLHidx <= (idxPassed + length(picksThisLabel)))
            highIdx = picksThisLabel(highLHidx - idxPassed);
        end
        if(lowLHidx > idxPassed && lowLHidx <= (idxPassed + length(picksThisLabel)))
            lowIdx = picksThisLabel(lowLHidx - idxPassed);
        end
        
        idxPassed = idxPassed + length(picksThisLabel);
    end
    
    
    %% Gets the images of their neighbours
    dirHigh = ['ntest=' num2str(ntest) ' high_LH_neighbours'];
    dirLow = ['ntest=' num2str(ntest) ' low_LH_neighbours'];
    if(isdir(dirHigh))
        rmdir(dirHigh, 's');
    end
    if(isdir(dirLow))
        rmdir(dirLow, 's');
    end
    mkdir(dirHigh); mkdir(dirLow);
    
    locationHigh = struct('original_name', {}, 'folder', {}, 'this_name', {}, 'position', {});
    locationLow = struct('original_name', {}, 'folder', {}, 'this_name', {}, 'position', {});
    
    foundHigh = false;
    foundLow = false;
    countHigh = 1;
    countLow = 1;
    i = 1;
    idxPassed = 0;
    lenFiles = length(dirList);
    while((countHigh <= numNeighbours || countLow <= numNeighbours || foundHigh || foundLow) && i <= lenFiles)
        
        names = dir([save_path '/' dirList{i} '/*' format]);
        lenSamples = length(names);
        
        % High's neighbours
        while(countHigh <= numNeighbours && (idx(1,countHigh)-idxPassed) <= lenSamples)
            copyfile([save_path '/' dirList{i} '/' names(idx(1,countHigh)-idxPassed).name], [dirHigh '/' num2str(countHigh) '_label' num2str(labels(1,countHigh)) '.jpg']);
            locationHigh(countHigh).original_name = names(idx(1,countHigh)-idxPassed).name;
            locationHigh(countHigh).position = idx(1,countHigh)-idxPassed;
            locationHigh(countHigh).folder = dirList{i};
            locationHigh(countHigh).this_name = [num2str(countHigh) '_label' num2str(labels(1,countHigh)) '.jpg'];
            countHigh = countHigh+1;
        end
        
        % Low's neighbours
        while(countLow <= numNeighbours && (idx(2,countLow)-idxPassed) <= lenSamples)
            copyfile([save_path '/' dirList{i} '/' names(idx(2,countLow)-idxPassed).name], [dirLow '/' num2str(countLow) '_label' num2str(labels(2,countLow)) '.jpg']);
            locationLow(countLow).original_name = names(idx(2,countLow)-idxPassed).name;
            locationLow(countLow).position = idx(2,countLow)-idxPassed;
            locationLow(countLow).folder = dirList{i};
            locationLow(countLow).this_name = [num2str(countLow) '_label' num2str(labels(2,countLow)) '.jpg'];
            countLow = countLow+1;
        end
        
        % High image
        if(~foundHigh && (highIdx-idxPassed) <= lenSamples)
            copyfile([save_path '/' dirList{i} '/' names(highIdx-idxPassed).name], [dirHigh '/highLikelihood_label' num2str(labelHigh) '.jpg']);
            locationHigh(numNeighbours+1).original_name = names(highIdx-idxPassed).name;
            locationHigh(numNeighbours+1).position = highIdx-idxPassed;
            locationHigh(numNeighbours+1).folder = dirList{i};
            locationHigh(numNeighbours+1).this_name = ['highLikelihood_label' num2str(labelHigh) '.jpg'];
            foundHigh = true;
        end
        
        % Low image
        if(~foundLow && (lowIdx-idxPassed) <= lenSamples)
            copyfile([save_path '/' dirList{i} '/' names(lowIdx-idxPassed).name], [dirLow '/lowLikelihood_label' num2str(labelLow) '.jpg']);
            locationLow(numNeighbours+1).original_name = names(lowIdx-idxPassed).name;
            locationLow(numNeighbours+1).position = lowIdx-idxPassed;
            locationLow(numNeighbours+1).folder = dirList{i};
            locationLow(numNeighbours+1).this_name = ['lowLikelihood_label' num2str(labelLow) '.jpg'];
            foundLow = true;
        end
        
        idxPassed = idxPassed + lenSamples;
        i = i+1;
    end
    save([dirHigh '/locationHigh.mat'], 'locationHigh');
    save([dirLow '/locationLow.mat'], 'locationLow');

end