% Auxiliar function

% Displays a figure to see the comparison #TP vs #FP for different margins
% of likelihoods
% function showFigureSpecVsSens(ids, lhTP, lhFP, lhTN, lhFN, marginsLH, numClasses, numTests)
function showFigurePrecVsMarg(ids, lhTP, lhFP, marginsLH, numClasses, numTests, testFolder)

    precVSlh = struct('precision', {}, 'likelihood', {});

    lenMargins = length(marginsLH);
    countMarginsTP = zeros(numClasses, lenMargins-1, 1);
    countMarginsFP = zeros(numClasses, lenMargins-1, 1);
%     countMarginsTN = zeros(numClasses, lenMargins-1, 1);
%     countMarginsFN = zeros(numClasses, lenMargins-1, 1);
    sensitivityMargins = zeros(lenMargins-1,1);
    specificityMargins = zeros(lenMargins-1,1);

    for i = 1:numClasses
        for j = 1:numTests
            % Counts TP
            len = length(lhTP{i}{j});
            for k = 1:len
                l = 1;
                while(l <= lenMargins && marginsLH(l) < lhTP{i}{j}{k})
                    l = l+1;
                end
                countMarginsTP(i, l-1) = countMarginsTP(i, l-1) + 1;
            end
            
            % Counts FP
            len = length(lhFP{i}{j});
            for k = 1:len
                l = 1;
                while(l <= lenMargins && marginsLH(l) < lhFP{i}{j}{k})
                    l = l+1;
                end
                
                countMarginsFP(i, l-1) = countMarginsFP(i, l-1) + 1;
                
%                 if(l == 1) % if lhFP{i}{j}{k} == 0
%                     countMarginsFP(i, 1) = countMarginsFP(i, 1) + 1;
%                 else
%                     countMarginsFP(i, l-1) = countMarginsFP(i, l-1) + 1;
%                 end
            end
            
%             % Counts TN
%             len = length(lhTN{i}{j});
%             for k = 1:len
%                 l = 1;
%                 while(l <= lenMargins && marginsLH(l) < lhTN{i}{j}{k})
%                     l = l+1;
%                 end
%                 countMarginsTN(i, l-1) = countMarginsTN(i, l-1) + 1;
%             end
%             
%             % Counts FN
%             len = length(lhFN{i}{j});
%             for k = 1:len
%                 l = 1;
%                 while(l <= lenMargins && marginsLH(l) < lhFN{i}{j}{k})
%                     l = l+1;
%                 end
%                 countMarginsFN(i, l-1) = countMarginsFN(i, l-1) + 1;
%             end
            
        end
    end
    
    
    acumTP = fliplr(cumsum(fliplr(countMarginsTP),2));
    acumFP = fliplr(cumsum(fliplr(countMarginsFP),2));
    
%     for i = (lenMargins-1):-1:1
%         sumTP = sum(countMarginsTP);
%         sumTP = sum(sumTP(i:lenMargins-1));
%         sumFP = sum(countMarginsFP);
%         sumFP = sum(sumFP(i:lenMargins-1));
%         sumTN = sum(countMarginsTN);
%         sumTN = sum(sumTN(i:lenMargins-1));
%         sumFN = sum(countMarginsFN);
%         sumFN = sum(sumFN(i:lenMargins-1));
%         sensitivityMargins(i) = sumTP/(sumTP+sumFN);
%         specificityMargins(i) = (1 - sumTN/(sumTN+sumFP));
%     end
    
    precission = acumTP./(acumTP+acumFP);
    marginsLabels = [];
    margins = [];
    for i = 1:length(marginsLH)-1
        marginsLabels = [marginsLabels; {[num2str(marginsLH(i)) ' - ' num2str(marginsLH(i+1))]}];
        margins = [margins; (marginsLH(i)+marginsLH(i+1))/2];
    end
    
    for i = 1:numClasses
        fig_h = figure;
        
        bar(margins, precission(i,:));
        
        precVSlh(i).precision = precission(i,:);
        precVSlh(i).likelihood = margins;

        x = margins;
        % Set the X-Tick locations
        Xt = margins;
        Xl = [0 marginsLH(end)];
        set(gca,'XTick',Xt,'XLim',Xl);
        
        % Reduce the size of the axis so that all the labels fit in the figure.
        pos = get(gca,'Position');
        set(gca,'Position',[pos(1), 0.2, pos(3) .7])
        
        ax = axis; % Current axis limits
        axis(axis); % Set the axis limit modes (e.g. XLimMode) to manual
        Yl = ax(1:2); % Y-axis limits

        % Place the text labels
        t = text(Xt,Yl(1)*ones(1,length(precission(i,:))), marginsLabels);
        set(t,'HorizontalAlignment','right','VerticalAlignment','middle','Rotation',90);

        % Remove the default labels
        set(gca,'XTickLabel','');
        
        
        title({'Precision vs Likelihood'; ids{i}});
        ylabel('Precision');
        
        saveas(fig_h, [testFolder '/PrecissionVSLikelihood_' ids{i}], 'jpg');
        
    end
    
    save([testFolder '/precVSlh.mat'], 'precVSlh');

end