function [specificity, sensitivity, resolutions] = parseResultFile(file_path)

    %% Gets the resolutions folders and sorts them
    resolutions = dir(file_path);
    resolutions = resolutions(3:length(resolutions));
    tmp = {};
    res1 = [];
    res2 = {};
    count = 1;
    for i = 1:length(resolutions)
        if(isdir([file_path '/' resolutions(i).name]))
           
            tmp{count} = resolutions(i).name;
            vals = regexp(tmp{count}, 'x', 'split');
            res1 = [res1; str2num(vals{1})];
            res2{count} = vals{2};
            count = count+1;
            
        end
    end
    res3 = sort(res1);
    resolutions = {};
    i = 1;
    while i <= length(res3)
        pos = find(res1==res3(i));
        count = 0;
        for j = 1:length(pos)
            resolutions{i+j-1} = [num2str(res1(pos(j))) 'x' res2{pos(j)}];
            count = count+1;
        end
        i = i+count;
    end

    
    %% Gets the paths to all the result files
    result_files = {};
    type_files = {};
    for i = 1:length(resolutions)
        
        % Old structure
%         res_path = [file_path '/' resolutions{i}];
%         testsdirs = dir(res_path);
%         test_path = [res_path '/' testsdirs(length(testsdirs)).name];
        % New structure
        test_path = [file_path '/' resolutions{i}];
        if(exist([test_path '/test_results.mat']))
            result_files{i} = [test_path '/test_results.mat'];
            type_files{i} = 'mat';
        else
            result_files{i} = [test_path '/test_results.rtf'];
            type_files{i} = 'rtf';
        end
        
    end
    
    %% Gets the specificity and sensitivity for each test and each class
    specificity = [];
    sensitivity = [];
    for i = 1:length(resolutions)
        
        if(strcmp(type_files{i}, 'rtf'))
            
            classes = [];
            data_file = importdata(result_files{i});
            data_file = data_file(6:end);
            j = 4;
            while(j <= length(data_file))

                part = regexp(data_file(j), ',', 'split');
                spec = regexp(part{1}(1), ' ', 'split');
                spec = spec{1}(length(spec{1}));
                spec = spec{1};
                sens = regexp(part{1}(2), ' ', 'split');
                sens = sens{1}(length(sens{1}));
                sens = sens{1}(1:end-1);

                classes = [classes; str2num(spec) str2num(sens)];

                j = j+4;

            end

            specificity = [specificity; classes(:,1)'];
            sensitivity = [sensitivity; classes(:,2)'];
            
        elseif(strcmp(type_files{i}, 'mat'))
            
            test_results = load(result_files{i});
            test_results = test_results.test_results;
            
            spec = [];
            sens = [];
            for j = 1:length(test_results)
                spec = [spec test_results(j).specificity];
                sens = [sens test_results(j).sensitivity];
            end
            
            specificity = [specificity; spec];
            sensitivity = [sensitivity; sens];
            
        end
        
    end


end